@@ -21,7 +21,7 @@
 
 /*! \file auth.h
  * \brief A header for the ident functions.
- * \version $Id: auth.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: auth.h 7329 2016-02-18 21:07:50Z michael $
  */
 
 #ifndef INCLUDED_auth_h
@@ -58,7 +58,7 @@ struct AuthRequest
   unsigned int flags;     /**< Current state of request. */
   struct Client *client;  /**< Pointer to Client structure for request. */
   fde_t fd;               /**< File descriptor for identd queries. */
-  time_t timeout;         /**< Time when query expires. */
+  uintmax_t timeout;      /**< Time when query expires. */
 };
 
 extern void auth_init(void);
