@@ -21,7 +21,7 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: conf.h 7534 2016-04-11 14:46:54Z michael $
  */
 
 #ifndef INCLUDED_conf_h
@@ -29,6 +29,7 @@
 #include "config.h"
 #include "client.h"
 #include "conf_class.h"
+#include "tls.h"
 
 
 #define CONF_NOREASON "<No reason supplied>"
@@ -75,37 +76,14 @@ enum
 #define SetConfDatabase(x)        ((x)->flags |= CONF_FLAGS_IN_DATABASE)
 
 
-/* shared/cluster server entry types
- * These defines are used for both shared and cluster.
- */
-enum
-{
-  SHARED_KLINE   = 0x00000001U,
-  SHARED_UNKLINE = 0x00000002U,
-  SHARED_XLINE   = 0x00000004U,
-  SHARED_UNXLINE = 0x00000008U,
-  SHARED_RESV    = 0x00000010U,
-  SHARED_UNRESV  = 0x00000020U,
-  SHARED_LOCOPS  = 0x00000040U,
-  SHARED_DLINE   = 0x00000080U,
-  SHARED_UNDLINE = 0x00000100U,
-  SHARED_ALL     = 0xFFFFFFFFU
-};
-
 enum maskitem_type
 {
-  CONF_CLIENT  = 1 <<  0,
-  CONF_SERVER  = 1 <<  1,
-  CONF_KLINE   = 1 <<  2,
-  CONF_DLINE   = 1 <<  3,
-  CONF_EXEMPT  = 1 <<  4,
-  CONF_CLUSTER = 1 <<  5,
-  CONF_XLINE   = 1 <<  6,
-  CONF_SHARED  = 1 <<  7,
-  CONF_CRESV   = 1 <<  8,
-  CONF_NRESV   = 1 <<  9,
-  CONF_SERVICE = 1 << 10,
-  CONF_OPER    = 1 << 11
+  CONF_CLIENT  = 1 << 0,
+  CONF_SERVER  = 1 << 1,
+  CONF_KLINE   = 1 << 2,
+  CONF_DLINE   = 1 << 3,
+  CONF_EXEMPT  = 1 << 4,
+  CONF_OPER    = 1 << 5
 };
 
 #define IsConfKill(x)           ((x)->type == CONF_KLINE)
@@ -139,21 +117,19 @@ struct MaskItem
   dlink_node         node;
   dlink_list         leaf_list;
   dlink_list         hub_list;
-  dlink_list         exempt_list;
   enum maskitem_type type;
   unsigned int       dns_failed;
   unsigned int       dns_pending;
   unsigned int       flags;
   unsigned int       modes;
   unsigned int       port;
-  unsigned int       count;
   unsigned int       aftype;
   unsigned int       active;
   unsigned int       htype;
   unsigned int       ref_count;  /* Number of *LOCAL* clients using this */
   int                bits;
-  time_t             until;     /* Hold action until this time (calendar time) */
-  time_t             setat;
+  uintmax_t          until;     /* Hold action until this time (calendar time) */
+  uintmax_t          setat;
   struct irc_ssaddr  bind;  /* ip to bind to for outgoing connect */
   struct irc_ssaddr  addr;  /* ip to connect to */
   struct ClassItem  *class;  /* Class of connection */
@@ -166,21 +142,6 @@ struct MaskItem
   char              *certfp;
   char              *whois;
   char              *cipher_list;
-  void              *rsa_public_key;
-};
-
-struct exempt
-{
-  dlink_node node;
-  char *name;
-  char *user;
-  char *host;
-  size_t len;
-  time_t when;
-  struct irc_ssaddr addr;
-  int bits;
-  int type;
-  int country_id;
 };
 
 struct CidrItem
@@ -217,6 +178,7 @@ struct config_general_entry
   unsigned int anti_spam_exit_message_time;
   unsigned int max_accept;
   unsigned int max_watch;
+  unsigned int whowas_history_length;
   unsigned int away_time;
   unsigned int away_count;
   unsigned int max_nick_time;
@@ -285,22 +247,26 @@ struct config_serverhide_entry
 
 struct config_serverinfo_entry
 {
-#ifdef HAVE_LIBCRYPTO
-  const EVP_MD *message_digest_algorithm;
-#endif
   char *sid;
   char *name;
   char *description;
   char *network_name;
   char *network_desc;
+  char *libgeoip_ipv4_database_file;
+  char *libgeoip_ipv6_database_file;
   char *rsa_private_key_file;
-  void *rsa_private_key;
-  void *server_ctx;
-  void *client_ctx;
+  char *ssl_certificate_file;
+  char *ssl_dh_param_file;
+  char *ssl_dh_elliptic_curve;
+  char *ssl_cipher_list;
+  char *ssl_message_digest_algorithm;
+  tls_context_t tls_ctx;
+  tls_md_t message_digest_algorithm;
   unsigned int hub;
   unsigned int default_max_clients;
   unsigned int max_nick_length;
   unsigned int max_topic_length;
+  unsigned int libgeoip_database_options;
   unsigned int specific_ipv4_vhost;
   unsigned int specific_ipv6_vhost;
   struct irc_ssaddr ip;
@@ -320,14 +286,8 @@ struct config_log_entry
 };
 
 extern dlink_list flatten_links;
-extern dlink_list server_items;
-extern dlink_list cluster_items;
-extern dlink_list gecos_items;
-extern dlink_list shared_items;
+extern dlink_list connect_items;
 extern dlink_list operator_items;
-extern dlink_list service_items;
-extern dlink_list nresv_items;
-extern dlink_list cresv_items;
 extern struct conf_parser_context conf_parser_ctx;
 extern struct config_log_entry ConfigLog;
 extern struct config_general_entry ConfigGeneral;
@@ -337,7 +297,7 @@ extern struct config_serverinfo_entry ConfigServerInfo;
 extern struct config_admin_entry ConfigAdminInfo;
 
 extern int valid_wild_card_simple(const char *);
-extern int valid_wild_card(struct Client *, int, ...);
+extern int valid_wild_card(int, ...);
 /* End GLOBAL section */
 
 extern struct MaskItem *conf_make(enum maskitem_type);
@@ -352,10 +312,8 @@ extern struct MaskItem *find_conf_name(dlink_list *, const char *, enum maskitem
 extern int conf_connect_allowed(struct irc_ssaddr *, int);
 extern const char *oper_privs_as_string(const unsigned int);
 extern void split_nuh(struct split_nuh_item *);
-extern struct MaskItem *find_matching_name_conf(enum maskitem_type, const char *,
-                                                const char *, const char *, unsigned int);
-extern struct MaskItem *find_exact_name_conf(enum maskitem_type, const struct Client *, const char *,
-                                             const char *, const char *);
+extern struct MaskItem *operator_find(const struct Client *, const char *);
+extern struct MaskItem *connect_find(const char *, const char *, int (*)(const char *, const char *));
 extern void conf_free(struct MaskItem *);
 extern void yyerror(const char *);
 extern void conf_error_report(const char *);
@@ -367,16 +325,13 @@ extern void conf_add_class_to_conf(struct MaskItem *, const char *);
 extern const char *get_oper_name(const struct Client *);
 
 /* XXX should the parse_aline stuff go into another file ?? */
-#define AWILD 0x1  /* check wild cards */
 extern int parse_aline(const char *, struct Client *, int, char **,
-                       int, char **, char **, time_t *, char **, char **);
+                       char **, char **, uintmax_t *, char **, char **);
 
 #define TK_SECONDS 0
 #define TK_MINUTES 1
-extern time_t valid_tkline(const char *, const int);
+extern uintmax_t valid_tkline(const char *, const int);
 extern int match_conf_password(const char *, const struct MaskItem *);
 
 enum { CLEANUP_TKLINES_TIME = 60 };
-
-extern void cluster_a_line(struct Client *, const char *, unsigned int, unsigned int, const char *,...);
 #endif /* INCLUDED_s_conf_h */
