@@ -21,14 +21,14 @@
 
 /*! \file fdlist.h
  * \brief The file descriptor list header.
- * \version $Id: fdlist.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: fdlist.h 7347 2016-02-21 11:44:24Z michael $
  */
 
 #ifndef INCLUDED_fdlist_h
 #define INCLUDED_fdlist_h
-#define FILEIO_V2
 
 #include "ircd_defs.h"
+#include "tls.h"
 
 
 enum { FD_DESC_SIZE = 128 };  /* hostlen + comment */
@@ -45,7 +45,6 @@ enum
   COMM_ERR_MAX
 };
 
-struct _fde;
 struct Client;
 
 typedef struct _fde
@@ -65,10 +64,10 @@ typedef struct _fde
   void *write_data;
   void (*timeout_handler)(struct _fde *, void *);
   void *timeout_data;
-  time_t timeout;
+  uintmax_t timeout;
   void (*flush_handler)(struct _fde *, void *);
   void *flush_data;
-  time_t flush_timeout;
+  uintmax_t flush_timeout;
 
   struct
   {
@@ -85,9 +84,8 @@ typedef struct _fde
     void *data;
     /* We'd also add the retry count here when we get to that -- adrian */
   } connect;
-#ifdef HAVE_LIBCRYPTO
-  SSL *ssl;
-#endif
+
+  tls_data_t ssl;
   struct _fde *hnext;
 } fde_t;
 
