@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: ircd.h 7329 2016-02-18 21:07:50Z michael $
  */
 
 
@@ -54,8 +54,8 @@ struct ServerStatistics
   uintmax_t        is_sbs;  /* bytes sent to servers */
   uintmax_t        is_sbr;  /* bytes received from servers */
 
-  time_t          is_cti;  /* time spent connected by clients */
-  time_t          is_sti;  /* time spent connected by servers */
+  uintmax_t        is_cti;  /* time spent connected by clients */
+  uintmax_t        is_sti;  /* time spent connected by servers */
 
   unsigned int    is_cl;   /* number of client connections */
   unsigned int    is_sv;   /* number of server connections */
@@ -91,9 +91,15 @@ struct ServerState_t
   unsigned int foreground;
 };
 
+struct ServerTime
+{
+  uintmax_t tv_sec, tv_usec;
+};
+
 
 #ifdef HAVE_LIBGEOIP
-extern GeoIP *geoip_ctx;
+extern GeoIP *GeoIPv4_ctx;
+extern GeoIP *GeoIPv6_ctx;
 #endif
 extern char **myargv;
 extern const char *infotext[];
@@ -108,7 +114,7 @@ extern struct ServerStatistics ServerStats;
 extern struct SetOptions GlobalSetOptions;
 extern struct ServerState_t server_state;
 extern struct event event_write_links_file;
-extern struct timeval SystemTime;
+extern struct ServerTime SystemTime;
 #define CurrentTime SystemTime.tv_sec
 
 extern void set_time(void);
