@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2015 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,11 +21,11 @@
 
 /*! \file ircd_getopt.h
  * \brief A header for the getopt() command line option calls.
- * \version $Id: ircd_getopt.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: ircd_getopt.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef __GETOPT_H_INCLUDED__
-#define __GETOPT_H_INCLUDED__
+#ifndef INCLUDED_ircd_getopt_h
+#define INCLUDED_ircd_getopt_h
 
 struct lgetopt
 {
@@ -36,4 +36,4 @@ struct lgetopt
 };
 
 extern void parseargs(int *, char ***, struct lgetopt *);
-#endif /* __GETOPT_H_INCLUDED__ */
+#endif /* INCLUDED_ircd_getopt_h */
