@@ -21,7 +21,7 @@
 
 /*! \file listener.h
  * \brief A header for the listener code.
- * \version $Id: listener.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: listener.h 7350 2016-02-21 11:56:06Z michael $
  */
 
 #ifndef INCLUDED_listener_h
@@ -53,5 +53,6 @@ extern const dlink_list *listener_get_list(void);
 extern void listener_add(int, const char *, unsigned int);
 extern void listener_release(struct Listener *);
 extern void listener_close_marked(void);
-extern const char *listener_get_name(const struct Listener *const);
+extern const char *listener_get_name(const struct Listener *);
+extern void listener_count_memory(unsigned int *, size_t *);
 #endif
