@@ -21,19 +21,17 @@
 
 /*! \file misc.h
  * \brief A header for the miscellaneous functions.
- * \version $Id: misc.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: misc.h 7329 2016-02-18 21:07:50Z michael $
  */
 
 #ifndef INCLUDED_misc_h
 #define INCLUDED_misc_h
 
-extern const char *date(time_t);
-extern const char *date_iso8601(time_t);
-extern const char *date_ctime(time_t);
-extern const char *time_dissect(time_t);
-#ifdef HAVE_LIBCRYPTO
-extern const char *ssl_get_cipher(const SSL *);
-#endif
+extern const char *date(uintmax_t);
+extern const char *date_iso8601(uintmax_t);
+extern const char *date_ctime(uintmax_t);
+extern const char *time_dissect(uintmax_t);
+extern void binary_to_hex(const unsigned char *, char *, unsigned int);
 
 /* Just blindly define our own MIN/MAX macro */
 #define IRCD_MAX(a, b)  ((a) > (b) ? (a) : (b))
