@@ -21,7 +21,7 @@
 
 /*! \file modules.h
  * \brief A header for the modules functions.
- * \version $Id: modules.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: modules.h 7498 2016-03-22 19:46:44Z michael $
  */
 
 #ifndef INCLUDED_modules_h
@@ -47,14 +47,14 @@ struct module
 struct module_path
 {
   dlink_node node;
-  char path[HYB_PATH_MAX + 1];
+  char *path;
 };
 
 
 extern dlink_list *modules_get_list(void);
 /* add a path */
 extern void mod_add_path(const char *);
-extern void mod_clear_paths(void);
+extern void modules_conf_clear(void);
 
 /* load all modules */
 extern void load_all_modules(int);
