@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 2000 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (c) 2013-2014 ircd-hybrid development team
+ *  Copyright (c) 2013-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,12 +22,11 @@
 
 /*! \file motd.h
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: motd.h 7329 2016-02-18 21:07:50Z michael $
  */
 
 #ifndef INCLUDED_motd_h
 #define INCLUDED_motd_h
-struct Client;
 
 /** Type of MOTD. */
 enum MotdType
@@ -55,9 +54,9 @@ struct Motd
 };
 
 /** Length of one MOTD line(80 chars + '\\0'). */
-#define MOTD_LINESIZE   81
+enum { MOTD_LINESIZE  =  81 };
 /** Maximum number of lines for MOTD */
-#define MOTD_MAXLINES   100
+enum { MOTD_MAXLINES  = 100 };
 
 
 /** Cache entry for the contents of a MOTD file. */
@@ -68,7 +67,7 @@ struct MotdCache
   unsigned int ref;      /**< Number of references to this entry. */
   unsigned int maxcount; /**< Number of lines allocated for message. */
   unsigned int count;    /**< Actual number of lines used in message. */
-  struct tm    modtime;  /**< Last modification time from file. */
+  uintmax_t    modtime;  /**< Last modification time from file. */
   char         motd[][MOTD_LINESIZE]; /**< Message body. */
 };
 
