@@ -21,7 +21,7 @@
 
 /*! \file numeric.h
  * \brief Declarations of numeric replies.
- * \version $Id: numeric.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: numeric.h 7477 2016-03-15 19:28:12Z michael $
  */
 
 #ifndef INCLUDED_numeric_h
@@ -69,12 +69,6 @@ enum irc_numerics
   RPL_STATSQLINE           = 217,
   RPL_STATSYLINE           = 218,
   RPL_ENDOFSTATS           = 219,
-
-  /*
-   * Note ircu uses 217 for STATSPLINE frip. conflict
-   * as RPL_STATSQLINE was used in old 2.8 for Q line
-   * I'm going to steal 220 for now *sigh* -Dianora
-   */
   RPL_STATSPLINE           = 220,
   RPL_UMODEIS              = 221,
   RPL_STATSDLINE           = 225,
@@ -98,7 +92,7 @@ enum irc_numerics
   RPL_ADMINLOC1            = 257,
   RPL_ADMINLOC2            = 258,
   RPL_ADMINEMAIL           = 259,
-  RPL_ENDOFTRACE           = 262,
+  RPL_TRACEEND             = 262,
   RPL_LOAD2HI              = 263,
   RPL_LOCALUSERS           = 265,
   RPL_GLOBALUSERS          = 266,
@@ -180,7 +174,6 @@ enum irc_numerics
   ERR_WILDTOPLEVEL         = 414,
   ERR_UNKNOWNCOMMAND       = 421,
   ERR_NOMOTD               = 422,
-  ERR_NOADMININFO          = 423,
   ERR_TOOMANYAWAY          = 429,
   ERR_NONICKNAMEGIVEN      = 431,
   ERR_ERRONEUSNICKNAME     = 432,
