@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_nick.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -32,11 +32,11 @@
 #include "ircd.h"
 #include "numeric.h"
 #include "conf.h"
+#include "conf_resv.h"
 #include "user.h"
 #include "whowas.h"
 #include "send.h"
 #include "channel_mode.h"
-#include "resv.h"
 #include "parse.h"
 #include "modules.h"
 #include "packet.h"
@@ -294,7 +294,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
   {
     DelUMode(source_p, UMODE_REGISTERED);
     watch_check_hash(source_p, RPL_LOGOFF);
-    source_p->tsinfo = strtoimax(parv[2], NULL, 10);
+    source_p->tsinfo = strtoumax(parv[2], NULL, 10);
     assert(source_p->tsinfo > 0);
   }
 
@@ -344,7 +344,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   client_p = make_client(source_p->from);
   client_p->servptr = source_p;
   client_p->hopcount = atoi(parv[2]);
-  client_p->tsinfo = strtoimax(parv[3], NULL, 10);
+  client_p->tsinfo = strtoumax(parv[3], NULL, 10);
 
   strlcpy(client_p->account, parv[9], sizeof(client_p->account));
   strlcpy(client_p->name, parv[1], sizeof(client_p->name));
@@ -401,7 +401,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
                                   int parc, char *parv[])
 {
   const char *uid = parv[8];
-  time_t newts = strtoimax(parv[3], NULL, 10);
+  uintmax_t newts = strtoumax(parv[3], NULL, 10);
   int sameuser = 0;
 
   assert(IsServer(source_p));
@@ -488,7 +488,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                              int parc, char *parv[])
 {
   int sameuser = 0;
-  time_t newts = strtoimax(parv[2], NULL, 10);
+  uintmax_t newts = strtoumax(parv[2], NULL, 10);
 
   assert(IsClient(source_p));
   assert(IsClient(target_p));
@@ -587,7 +587,7 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
 {
   char nick[NICKLEN + 1] = "";
   struct Client *target_p = NULL;
-  struct MaskItem *conf = NULL;
+  const struct ResvItem *resv = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -606,10 +606,9 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
   }
 
   /* Check if the nick is resv'd */
-  if ((conf = find_matching_name_conf(CONF_NRESV, nick, NULL, NULL, 0)))
+  if ((resv = resv_find(nick, match)))
   {
-    ++conf->count;
-    sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, conf->reason);
+    sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, resv->reason);
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
                          nick, get_client_name(source_p, HIDE_IP));
@@ -640,7 +639,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
 {
   char nick[NICKLEN + 1] = "";
   struct Client *target_p = NULL;
-  struct MaskItem *conf = NULL;
+  const struct ResvItem *resv = NULL;
 
   assert(MyClient(source_p));
 
@@ -666,10 +665,9 @@ m_nick(struct Client *source_p, int parc, char *parv[])
 
   if (!HasFlag(source_p, FLAGS_EXEMPTRESV) &&
       !(HasUMode(source_p, UMODE_OPER) && HasOFlag(source_p, OPER_FLAG_NICK_RESV)) &&
-      (conf = find_matching_name_conf(CONF_NRESV, nick, NULL, NULL, 0)))
+      (resv = resv_find(nick, match)))
   {
-    ++conf->count;
-    sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, conf->reason);
+    sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, resv->reason);
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
                          nick, get_client_name(source_p, HIDE_IP));
@@ -855,7 +853,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
