@@ -21,7 +21,7 @@
 
 /*! \file m_connect.c
  * \brief Includes required functions for processing the CONNECT command.
- * \version $Id: m_connect.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_connect.c 7524 2016-04-04 18:51:46Z michael $
  */
 
 #include "stdinc.h"
@@ -54,11 +54,11 @@
 static int
 mo_connect(struct Client *source_p, int parc, char *parv[])
 {
-  int port = 0, tmpport = 0;
   struct MaskItem *conf = NULL;
   const struct Client *target_p = NULL;
+  const char *const name = parv[1];
 
-  if (EmptyString(parv[1]))
+  if (EmptyString(name))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "CONNECT");
     return 0;
@@ -75,7 +75,8 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
     if (hunt_server(source_p, ":%s CONNECT %s %s :%s", 3, parc, parv) != HUNTED_ISME)
       return 0;
   }
-  else if (!HasOFlag(source_p, OPER_FLAG_CONNECT))
+
+  if (!HasOFlag(source_p, OPER_FLAG_CONNECT))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "connect");
     return 0;
@@ -84,54 +85,47 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
   /*
    * Try to find the name, then host, if both fail notify ops and bail
    */
-  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)) &&
-      !(conf = find_matching_name_conf(CONF_SERVER, NULL, NULL, parv[1], 0)))
+  if (!(conf = connect_find(name, NULL, match)) &&
+      !(conf = connect_find(NULL, name, match)))
   {
-    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", parv[1]);
+    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", name);
     return 0;
   }
 
   if ((target_p = hash_find_server(conf->name)))
   {
-    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s.",
+    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s",
                       target_p->name, target_p->from->name);
     return 0;
   }
 
   /*
    * Get port number from user, if given. If not specified,
-   * use the default from configuration structure. If missing
-   * from there, then use the precompiled default.
+   * use the default from configuration structure.
    */
-  tmpport = port = conf->port;
+  int port = 0;
 
   if (parc > 2 && !EmptyString(parv[2]))
+    port = atoi(parv[2]);
+  if (port == 0)
+    port = conf->port;
+  if (port <= 0)
   {
-    if ((port = atoi(parv[2])) <= 0)
-    {
-      sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
-      return 0;
-    }
-  }
-  else if (port <= 0 && (port = PORTNUM) <= 0)
-  {
-    sendto_one_notice(source_p, &me, ":Connect: missing port number");
+    sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
     return 0;
   }
 
   if (find_servconn_in_progress(conf->name))
   {
-    sendto_one_notice(source_p, &me, ":Connect: a connection to %s "
-                      "is already in progress.", conf->name);
+    sendto_one_notice(source_p, &me, ":Connect: a connection to %s is already in progress",
+                      conf->name);
     return 0;
   }
 
-  /*
-   * Notify all operators about remote connect requests
-   */
-  ilog(LOG_TYPE_IRCD, "CONNECT From %s : %s %s",
-       source_p->name, parv[1], parv[2] ? parv[2] : "");
+  ilog(LOG_TYPE_IRCD, "CONNECT %s %d from %s",
+       name, port, get_oper_name(source_p));
 
+  const int tmpport = conf->port;
   conf->port = port;
 
   /*
@@ -175,9 +169,9 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
 static int
 ms_connect(struct Client *source_p, int parc, char *parv[])
 {
-  int port = 0, tmpport = 0;
   struct MaskItem *conf = NULL;
   const struct Client *target_p = NULL;
+  const char *const name = parv[1];
 
   if (parc < 4 || EmptyString(parv[3]))
   {
@@ -191,52 +185,38 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
   /*
    * Try to find the name, then host, if both fail notify ops and bail
    */
-  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)) &&
-      !(conf = find_matching_name_conf(CONF_SERVER, NULL, NULL, parv[1], 0)))
+  if (!(conf = connect_find(name, NULL, match)) &&
+      !(conf = connect_find(NULL, name, match)))
   {
-    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", parv[1]);
+    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", name);
     return 0;
   }
 
   if ((target_p = hash_find_server(conf->name)))
   {
-    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s.",
+    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s",
                       target_p->name, target_p->from->name);
     return 0;
   }
 
   /*
    * Get port number from user, if given. If not specified,
-   * use the default from configuration structure. If missing
-   * from there, then use the precompiled default.
+   * use the default from configuration structure.
    */
-  tmpport = port = conf->port;
+  int port = atoi(parv[2]);
 
-  if (parc > 2 && !EmptyString(parv[2]))
+  if (port == 0)
+    port = conf->port;
+  if (port <= 0)
   {
-    port = atoi(parv[2]);
-
-    /*
-     * If someone sends port 0, and we have a config port.. use it
-     */
-    if (port == 0 && conf->port)
-      port = conf->port;
-    else if (port <= 0)
-    {
-      sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
-      return 0;
-    }
-  }
-  else if (port <= 0 && (port = PORTNUM) <= 0)
-  {
-    sendto_one_notice(source_p, &me, ":Connect: missing port number");
+    sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
     return 0;
   }
 
   if (find_servconn_in_progress(conf->name))
   {
-    sendto_one_notice(source_p, &me, ":Connect: a connection to %s "
-                      "is already in progress.", conf->name);
+    sendto_one_notice(source_p, &me, ":Connect: a connection to %s is already in progress",
+                      conf->name);
     return 0;
   }
 
@@ -244,14 +224,14 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
    * Notify all operators about remote connect requests
    */
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_GLOBAL, "from %s: Remote CONNECT %s %d from %s",
-                       me.name, parv[1], port, source_p->name);
-  sendto_server(NULL, 0, 0,
-                ":%s GLOBOPS :Remote CONNECT %s %d from %s",
-                me.id, parv[1], port, source_p->name);
+                       me.name, name, port, get_oper_name(source_p));
+  sendto_server(NULL, 0, 0, ":%s GLOBOPS :Remote CONNECT %s %d from %s",
+                me.id, name, port, get_oper_name(source_p));
 
-  ilog(LOG_TYPE_IRCD, "CONNECT From %s : %s %d",
-       source_p->name, parv[1], port);
+  ilog(LOG_TYPE_IRCD, "Remote CONNECT %s %d from %s",
+       name, port, get_oper_name(source_p));
 
+  const int tmpport = conf->port;
   conf->port = port;
 
   /*
@@ -298,7 +278,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7524 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
