@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_etrace.c 7045 2016-01-09 20:11:17Z michael $
  */
 
 #include "stdinc.h"
@@ -94,7 +94,7 @@ do_etrace(struct Client *source_p, const char *arg)
     if (target_p && MyConnect(target_p))
       report_this_status(source_p, target_p);
 
-    sendto_one_numeric(source_p, &me, RPL_ENDOFTRACE, tname);
+    sendto_one_numeric(source_p, &me, RPL_TRACEEND, tname);
     return;
   }
 
@@ -106,7 +106,7 @@ do_etrace(struct Client *source_p, const char *arg)
       report_this_status(source_p, target_p);
   }
 
-  sendto_one_numeric(source_p, &me, RPL_ENDOFTRACE, tname);
+  sendto_one_numeric(source_p, &me, RPL_TRACEEND, tname);
 }
 
 /* mo_etrace()
@@ -145,7 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7045 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
