@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_info.c 7436 2016-03-10 19:57:51Z michael $
  */
 
 #include "stdinc.h"
@@ -147,6 +147,18 @@ static const struct InfoStruct info_table[] =
     &ConfigServerInfo.max_topic_length,
     "Maximum topic length"
   },
+  {
+    "libgeoip_ipv4_database_file",
+    OUTPUT_STRING,
+    &ConfigServerInfo.libgeoip_ipv4_database_file,
+    "Path to the libGeoIP IPv4 database file"
+  },
+  {
+    "libgeoip_ipv6_database_file",
+    OUTPUT_STRING,
+    &ConfigServerInfo.libgeoip_ipv6_database_file,
+    "Path to the libGeoIP IPv6 database file"
+  },
   {
     "use_logging",
     OUTPUT_BOOLEAN_YN,
@@ -171,7 +183,6 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.invite_client_time,
     "How many invite_client_count invites are allowed in this time"
   },
-
   {
     "invite_delay_channel",
     OUTPUT_DECIMAL,
@@ -376,6 +387,12 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.max_accept,
     "Maximum nicknames on accept list"
   },
+  {
+    "whowas_history_length",
+    OUTPUT_DECIMAL,
+    &ConfigGeneral.whowas_history_length,
+    "Length of the WHOWAS nick name history list"
+  },
   {
     "anti_nick_flood",
     OUTPUT_BOOLEAN_YN,
@@ -682,7 +699,7 @@ send_info_text(struct Client *source_p)
 static int
 m_info(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
@@ -746,7 +763,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7436 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
