@@ -21,7 +21,7 @@
 
 /*! \file m_list.c
  * \brief Includes required functions for processing the LIST command.
- * \version $Id: m_list.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: m_list.c 7075 2016-01-20 11:47:29Z michael $
  */
 
 #include "stdinc.h"
@@ -42,7 +42,6 @@
 static void
 do_list(struct Client *source_p, char *arg)
 {
-  struct ListTask *lt = NULL;
   int no_masked_channels = 1;
 
   if (source_p->connection->list_task)
@@ -52,7 +51,7 @@ do_list(struct Client *source_p, char *arg)
     return;
   }
 
-  lt = xcalloc(sizeof(struct ListTask));
+  struct ListTask *lt = xcalloc(sizeof(struct ListTask));
   lt->users_max = UINT_MAX;
   lt->created_max = UINT_MAX;
   lt->topicts_max = UINT_MAX;
@@ -212,7 +211,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7033 $",
+  .version = "$Revision: 7075 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
