@@ -21,7 +21,7 @@
 
 /*! \file m_lusers.c
  * \brief Includes required functions for processing the LUSERS command.
- * \version $Id: m_lusers.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_lusers.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +51,7 @@
 static int
 m_lusers(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
   {
@@ -116,7 +116,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
