@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_module.c 7075 2016-01-20 11:47:29Z michael $
  */
 
 #include "stdinc.h"
@@ -192,8 +192,8 @@ module_list(struct Client *source_p, const char *arg)
 
 struct ModuleStruct
 {
-  const char *cmd;
-  void (*handler)(struct Client *, const char *);
+  const char *const cmd;
+  void (*const handler)(struct Client *, const char *);
   const unsigned int arg_required;
 };
 
@@ -283,7 +283,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7075 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_NOUNLOAD
