@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_oper.c 7402 2016-03-06 16:32:59Z michael $
  */
 
 #include "stdinc.h"
@@ -136,10 +136,10 @@ m_oper(struct Client *source_p, int parc, char *parv[])
   if (!IsFloodDone(source_p))
     flood_endgrace(source_p);
 
-  if ((conf = find_exact_name_conf(CONF_OPER, source_p, opername, NULL, NULL)) == NULL)
+  if ((conf = operator_find(source_p, opername)) == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOOPERHOST);
-    conf = find_exact_name_conf(CONF_OPER, NULL, opername, NULL, NULL);
+    conf = operator_find(NULL, opername);
     failed_oper_notice(source_p, opername, (conf != NULL) ?
                        "host mismatch" : "no operator {} block");
     return 0;
@@ -230,7 +230,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7402 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
