@@ -21,7 +21,7 @@
 
 /*! \file m_set.c
  * \brief Includes required functions for processing the SET command.
- * \version $Id: m_set.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_set.c 7406 2016-03-06 17:19:26Z michael $
  */
 
 #include "stdinc.h"
@@ -43,7 +43,7 @@ quote_autoconn(struct Client *source_p, const char *arg, int newval)
 {
   if (!EmptyString(arg))
   {
-    struct MaskItem *conf = find_exact_name_conf(CONF_SERVER, NULL, arg, NULL, NULL);
+    struct MaskItem *conf = connect_find(arg, NULL, irccmp);
 
     if (conf)
     {
@@ -54,9 +54,9 @@ quote_autoconn(struct Client *source_p, const char *arg, int newval)
 
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "%s has changed AUTOCONN for %s to %i",
-                           get_oper_name(source_p), arg, newval);
+                           get_oper_name(source_p), conf->name, newval);
       sendto_one_notice(source_p, &me, ":AUTOCONN for %s is now set to %i",
-                        arg, newval);
+                        conf->name, newval);
     }
     else
       sendto_one_notice(source_p, &me, ":Cannot find %s", arg);
@@ -226,8 +226,8 @@ quote_jfloodcount(struct Client *source_p, const char *arg, int newval)
 /* Structure used for the SET table itself */
 struct SetStruct
 {
-  const char *name;
-  void (*handler)(struct Client *, const char *, int);
+  const char *const name;
+  void (*const handler)(struct Client *, const char *, int);
   const unsigned int wants_char;  /* 1 if it expects (char *, [int]) */
   const unsigned int wants_int;  /* 1 if it expects ([char *], int) */
   /* eg:  0, 1 == only an int arg
@@ -406,7 +406,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7406 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
