@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_stats.c 7510 2016-03-26 19:48:19Z michael $
  */
 
 #include "stdinc.h"
@@ -32,18 +32,20 @@
 #include "listener.h"
 #include "conf.h"
 #include "conf_class.h"
+#include "conf_cluster.h"
+#include "conf_gecos.h"
+#include "conf_resv.h"
+#include "conf_service.h"
+#include "conf_shared.h"
 #include "hostmask.h"
 #include "numeric.h"
 #include "send.h"
 #include "fdlist.h"
 #include "misc.h"
 #include "server.h"
-#include "user.h"
 #include "event.h"
-#include "dbuf.h"
 #include "parse.h"
 #include "modules.h"
-#include "resv.h"
 #include "whowas.h"
 #include "watch.h"
 #include "reslib.h"
@@ -51,22 +53,117 @@
 #include "ipcache.h"
 
 
-static const struct shared_flags
+static void
+report_shared(struct Client *source_p)
 {
-  const unsigned int type;
-  const unsigned char letter;
-} flag_table[] = {
-  { SHARED_KLINE,   'K' },
-  { SHARED_UNKLINE, 'U' },
-  { SHARED_XLINE,   'X' },
-  { SHARED_UNXLINE, 'Y' },
-  { SHARED_RESV,    'Q' },
-  { SHARED_UNRESV,  'R' },
-  { SHARED_LOCOPS,  'L' },
-  { SHARED_DLINE,   'D' },
-  { SHARED_UNDLINE, 'E' },
-  { 0, '\0' }
-};
+  static const struct shared_types
+  {
+    unsigned int type;
+    unsigned char letter;
+  } flag_table[] = {
+    { SHARED_KLINE,   'K' },
+    { SHARED_UNKLINE, 'U' },
+    { SHARED_XLINE,   'X' },
+    { SHARED_UNXLINE, 'Y' },
+    { SHARED_RESV,    'Q' },
+    { SHARED_UNRESV,  'R' },
+    { SHARED_LOCOPS,  'L' },
+    { SHARED_DLINE,   'D' },
+    { SHARED_UNDLINE, 'E' },
+    { 0, '\0' }
+  };
+
+  dlink_node *node;
+  char buf[sizeof(flag_table) / sizeof(struct shared_types) + 1];  /* +1 for 'c' */
+
+  DLINK_FOREACH(node, shared_get_list()->head)
+  {
+    const struct SharedItem *shared = node->data;
+    char *p = buf;
+
+    *p++ = 'c';
+
+    for (const struct shared_types *tab = flag_table; tab->type; ++tab)
+      if (tab->type & shared->type)
+        *p++ = tab->letter;
+      else
+        *p++ = ToLower(tab->letter);
+
+    *p = '\0';
+
+    sendto_one_numeric(source_p, &me, RPL_STATSULINE, shared->server,
+                       shared->user, shared->host, buf);
+  }
+}
+
+static void
+report_cluster(struct Client *source_p)
+{
+  static const struct cluster_types
+  {
+    unsigned int type;
+    unsigned char letter;
+  } flag_table[] = {
+    { CLUSTER_KLINE,   'K' },
+    { CLUSTER_UNKLINE, 'U' },
+    { CLUSTER_XLINE,   'X' },
+    { CLUSTER_UNXLINE, 'Y' },
+    { CLUSTER_RESV,    'Q' },
+    { CLUSTER_UNRESV,  'R' },
+    { CLUSTER_LOCOPS,  'L' },
+    { CLUSTER_DLINE,   'D' },
+    { CLUSTER_UNDLINE, 'E' },
+    { 0, '\0' }
+  };
+
+  dlink_node *node;
+  char buf[sizeof(flag_table) / sizeof(struct cluster_types) + 1];  /* +1 for 'C' */
+
+  DLINK_FOREACH(node, cluster_get_list()->head)
+  {
+    const struct ClusterItem *cluster = node->data;
+    char *p = buf;
+
+    *p++ = 'C';
+
+    for (const struct cluster_types *tab = flag_table; tab->type; ++tab)
+      if (tab->type & cluster->type)
+        *p++ = tab->letter;
+      else
+        *p++ = ToLower(tab->letter);
+
+    *p = '\0';
+
+    sendto_one_numeric(source_p, &me, RPL_STATSULINE, cluster->server,
+                       "*", "*", buf);
+  }
+}
+
+static void
+stats_service(struct Client *source_p, int parc, char *parv[])
+{
+  dlink_node *node;
+
+  DLINK_FOREACH(node, service_get_list()->head)
+  {
+    const struct ServiceItem *service = node->data;
+    sendto_one_numeric(source_p, &me, RPL_STATSSERVICE, 'S', "*", service->name, 0, 0);
+  }
+}
+
+static void
+stats_gecos(struct Client *source_p, int parc, char *parv[])
+{
+  dlink_node *node;
+
+  DLINK_FOREACH(node, gecos_get_list()->head)
+  {
+    const struct GecosItem *gecos = node->data;
+    sendto_one_numeric(source_p, &me, RPL_STATSXLINE,
+                       gecos->expire ? 'x' : 'X',
+                       gecos->mask, gecos->reason);
+  }
+}
 
 /*
  * inputs	- pointer to client requesting confitem report
@@ -75,127 +172,62 @@ static const struct shared_flags
  * side effects	-
  */
 static void
-report_confitem_types(struct Client *source_p, enum maskitem_type type)
+stats_operator(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
-  const struct MaskItem *conf = NULL;
-  char buf[IRCD_BUFSIZE];
-  char *p = NULL;
+  dlink_node *node;
 
-  switch (type)
+  if (!HasUMode(source_p, UMODE_OPER) && ConfigGeneral.stats_o_oper_only)
   {
-    case CONF_XLINE:
-      DLINK_FOREACH(node, gecos_items.head)
-      {
-        conf = node->data;
-        sendto_one_numeric(source_p, &me, RPL_STATSXLINE,
-                           conf->until ? 'x': 'X', conf->count,
-                           conf->name, conf->reason);
-      }
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+    return;
+  }
 
-      break;
+  DLINK_FOREACH(node, operator_items.head)
+  {
+    const struct MaskItem *conf = node->data;
 
-    case CONF_SHARED:
-      DLINK_FOREACH(node, shared_items.head)
-      {
-        conf = node->data;
-        p = buf;
+    /* Don't allow non opers to see oper privs */
+    if (HasUMode(source_p, UMODE_OPER))
+      sendto_one_numeric(source_p, &me, RPL_STATSOLINE, 'O', conf->user, conf->host,
+                         conf->name, oper_privs_as_string(conf->port),
+                         conf->class->name);
+    else
+      sendto_one_numeric(source_p, &me, RPL_STATSOLINE, 'O', conf->user, conf->host,
+                         conf->name, "0", conf->class->name);
+  }
+}
 
-        *p++ = 'c';
+static void
+stats_connect(struct Client *source_p, int parc, char *parv[])
+{
+  dlink_node *node;
 
-        for (const struct shared_flags *shared = flag_table; shared->type; ++shared)
-          if (shared->type & conf->flags)
-            *p++ = shared->letter;
-          else
-            *p++ = ToLower(shared->letter);
+  DLINK_FOREACH(node, connect_items.head)
+  {
+    char buf[8];
+    char *p = buf;
+    const struct MaskItem *conf = node->data;
 
-        *p = '\0';
+    if (IsConfAllowAutoConn(conf))
+      *p++ = 'A';
+    if (IsConfSSL(conf))
+      *p++ = 'S';
+    if (p == buf)
+      *p++ = '*';
 
-        sendto_one_numeric(source_p, &me, RPL_STATSULINE, conf->name,
-                           conf->user ? conf->user: "*",
-                           conf->host ? conf->host: "*", buf);
-      }
+    *p = '\0';
 
-      DLINK_FOREACH(node, cluster_items.head)
-      {
-        conf = node->data;
-        p = buf;
-
-        *p++ = 'C';
-
-        for (const struct shared_flags *shared = flag_table; shared->type; ++shared)
-          if (shared->type & conf->flags)
-            *p++ = shared->letter;
-          else
-            *p++ = ToLower(shared->letter);
-
-        *p = '\0';
-
-        sendto_one_numeric(source_p, &me, RPL_STATSULINE, conf->name, "*", "*", buf);
-      }
-
-      break;
-
-    case CONF_OPER:
-      DLINK_FOREACH(node, operator_items.head)
-      {
-        conf = node->data;
-
-        /* Don't allow non opers to see oper privs */
-        if (HasUMode(source_p, UMODE_OPER))
-          sendto_one_numeric(source_p, &me, RPL_STATSOLINE, 'O', conf->user, conf->host,
-                             conf->name, oper_privs_as_string(conf->port),
-                             conf->class->name);
-        else
-          sendto_one_numeric(source_p, &me, RPL_STATSOLINE, 'O', conf->user, conf->host,
-                             conf->name, "0", conf->class->name);
-      }
-
-      break;
-
-    case CONF_SERVICE:
-      DLINK_FOREACH(node, service_items.head)
-      {
-        conf = node->data;
-        sendto_one_numeric(source_p, &me, RPL_STATSSERVICE, 'S', "*", conf->name, 0, 0);
-      }
-
-      break;
-
-    case CONF_SERVER:
-      DLINK_FOREACH(node, server_items.head)
-      {
-        p = buf;
-        conf = node->data;
-
-        buf[0] = '\0';
-
-        if (IsConfAllowAutoConn(conf))
-          *p++ = 'A';
-        if (IsConfSSL(conf))
-          *p++ = 'S';
-        if (buf[0] == '\0')
-          *p++ = '*';
-
-        *p = '\0';
-
-        /*
-         * Allow admins to see actual ips unless hide_server_ips is enabled
-         */
-        if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
-          sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C', conf->host,
-                             buf, conf->name, conf->port,
-                             conf->class->name);
-        else
-          sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C',
-                             "*@127.0.0.1", buf, conf->name, conf->port,
-                             conf->class->name);
-      }
-
-      break;
-
-    default:
-      break;
+    /*
+     * Allow admins to see actual ips unless hide_server_ips is enabled
+     */
+    if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
+      sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C', conf->host,
+                         buf, conf->name, conf->port,
+                         conf->class->name);
+    else
+      sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C',
+                         "*@127.0.0.1", buf, conf->name, conf->port,
+                         conf->class->name);
   }
 }
 
@@ -206,102 +238,33 @@ report_confitem_types(struct Client *source_p, enum maskitem_type type)
  * side effects - report all resvs to client.
  */
 static void
-report_resv(struct Client *source_p)
+stats_resv(struct Client *source_p, int parc, char *parv[])
 {
   const dlink_node *node = NULL;
 
-  DLINK_FOREACH(node, cresv_items.head)
+  DLINK_FOREACH(node, resv_chan_get_list()->head)
   {
-    const struct MaskItem *conf = node->data;
+    const struct ResvItem *resv = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_STATSQLINE,
-                       conf->until ? 'q' : 'Q', conf->count,
-                       conf->name, conf->reason);
+                       resv->expire ? 'q' : 'Q',
+                       resv->mask, resv->reason);
   }
 
-  DLINK_FOREACH(node, nresv_items.head)
+  DLINK_FOREACH(node, resv_nick_get_list()->head)
   {
-    const struct MaskItem *conf = node->data;
+    const struct ResvItem *resv = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_STATSQLINE,
-                       conf->until ? 'q' : 'Q', conf->count,
-                       conf->name, conf->reason);
+                       resv->expire ? 'q' : 'Q',
+                       resv->mask, resv->reason);
   }
 }
 
-/*
- * This is part of the STATS replies. There is no offical numeric for this
- * since this isn't an official command, in much the same way as HASH isn't.
- * It is also possible that some systems wont support this call or have
- * different field names for "struct rusage".
- * -avalon
- */
-static void
-stats_usage(struct Client *source_p, int parc, char *parv[])
-{
-  struct rusage rus;
-  time_t secs;
-  time_t rup;
-#ifdef  hz
-# define hzz hz
-#else
-# ifdef HZ
-#  define hzz HZ
-# else
-  int hzz = 1;
-# endif
-#endif
-
-  if (getrusage(RUSAGE_SELF, &rus) == -1)
-  {
-    sendto_one_notice(source_p, &me, ":Getruseage error: %s",
-                      strerror(errno));
-    return;
-  }
-
-  secs = rus.ru_utime.tv_sec + rus.ru_stime.tv_sec;
-
-  if (secs == 0)
-    secs = 1;
-
-  rup = (CurrentTime - me.connection->since) * hzz;
-
-  if (rup == 0)
-    rup = 1;
-
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :CPU Secs %d:%02d User %d:%02d System %d:%02d",
-                     (int)(secs/60), (int)(secs%60),
-                     (int)(rus.ru_utime.tv_sec/60), (int)(rus.ru_utime.tv_sec%60),
-                     (int)(rus.ru_stime.tv_sec/60), (int)(rus.ru_stime.tv_sec%60));
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :RSS %ld ShMem %ld Data %ld Stack %ld",
-                     rus.ru_maxrss,
-                     (rus.ru_ixrss / rup), (rus.ru_idrss / rup),
-                     (rus.ru_isrss / rup));
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :Swaps %d Reclaims %d Faults %d",
-                     (int)rus.ru_nswap,
-                     (int)rus.ru_minflt, (int)rus.ru_majflt);
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :Block in %d out %d",
-                     (int)rus.ru_inblock,
-                     (int)rus.ru_oublock);
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :Msg Rcv %d Send %d",
-                     (int)rus.ru_msgrcv,
-                     (int)rus.ru_msgsnd);
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "R :Signals %d Context Vol. %d Invol %d",
-                     (int)rus.ru_nsignals,
-                     (int)rus.ru_nvcsw, (int)rus.ru_nivcsw);
-}
-
 static void
 stats_memory(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *gptr = NULL;
-  const dlink_node *dlink = NULL;
+  const dlink_node *node, *node2;
 
   unsigned int local_client_conf_count = 0;      /* local client conf links */
   unsigned int users_counted = 0;                /* user structs */
@@ -313,7 +276,6 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   unsigned int channel_invex = 0;
 
   unsigned int wwu = 0;                  /* whowas users */
-  unsigned int class_count = 0;          /* classes */
   unsigned int aways_counted = 0;
   unsigned int number_ips_stored = 0;        /* number of ip addresses hashed */
 
@@ -326,12 +288,8 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   size_t safelist_memory = 0;
 
   size_t wwm = 0;               /* whowas array memory used       */
-  size_t conf_memory = 0;       /* memory used by conf lines      */
   size_t mem_ips_stored = 0;        /* memory used by ip address hash */
 
-  size_t total_channel_memory = 0;
-  size_t totww = 0;
-
   unsigned int local_client_count  = 0;
   unsigned int remote_client_count = 0;
 
@@ -345,10 +303,13 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   unsigned int watch_list_entries = 0;   /* watchlist entries     */
   size_t watch_list_memory = 0; /* watchlist memory used */
 
+  unsigned int listener_count = 0;
+  size_t listener_memory = 0;
 
-  DLINK_FOREACH(gptr, global_client_list.head)
+
+  DLINK_FOREACH(node, global_client_list.head)
   {
-    const struct Client *target_p = gptr->data;
+    const struct Client *target_p = node->data;
 
     if (MyConnect(target_p))
     {
@@ -371,16 +332,16 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   /* Count up all channels, ban lists, except lists, Invex lists */
   channel_memory = dlink_list_length(&channel_list) * sizeof(struct Channel);
 
-  DLINK_FOREACH(gptr, channel_list.head)
+  DLINK_FOREACH(node, channel_list.head)
   {
-    const struct Channel *chptr = gptr->data;
-
-    channel_members += dlink_list_length(&chptr->members);
-    channel_invites += dlink_list_length(&chptr->invites);
+    const struct Channel *chptr = node->data;
 
     if (chptr->topic[0])
       ++channel_topics;
 
+    channel_members += dlink_list_length(&chptr->members);
+    channel_invites += dlink_list_length(&chptr->invites);
+
     channel_bans += dlink_list_length(&chptr->banlist);
     channel_ban_memory += dlink_list_length(&chptr->banlist) * sizeof(struct Ban);
 
@@ -391,41 +352,26 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
     channel_invex_memory += dlink_list_length(&chptr->invexlist) * sizeof(struct Ban);
   }
 
-  if ((safelist_count = dlink_list_length(&listing_client_list)))
+  safelist_count = dlink_list_length(&listing_client_list);
+  if (safelist_count)
   {
     safelist_memory = safelist_count * sizeof(struct ListTask);
-    DLINK_FOREACH(gptr, listing_client_list.head)
+
+    DLINK_FOREACH(node, listing_client_list.head)
     {
-      const struct Client *acptr = gptr->data;
+      const struct Client *acptr = node->data;
 
-      DLINK_FOREACH(dlink, acptr->connection->list_task->show_mask.head)
-        safelist_memory += strlen(dlink->data);
+      DLINK_FOREACH(node2, acptr->connection->list_task->show_mask.head)
+        safelist_memory += strlen(node2->data);
 
-      DLINK_FOREACH(dlink, acptr->connection->list_task->hide_mask.head)
-        safelist_memory += strlen(dlink->data);
+      DLINK_FOREACH(node2, acptr->connection->list_task->hide_mask.head)
+        safelist_memory += strlen(node2->data);
     }
   }
 
-#if 0
-  /* XXX THIS has to be fixed !!!! -db */
-  /* count up all config items */
-  DLINK_FOREACH(dlink, ConfigItemList.head)
-  {
-      aconf = dlink->data;
-      conf_memory += aconf->host ? strlen(aconf->host)+1 : 0;
-      conf_memory += aconf->passwd ? strlen(aconf->passwd)+1 : 0;
-      conf_memory += aconf->name ? strlen(aconf->name)+1 : 0;
-      conf_memory += sizeof(struct AccessItem);
-  }
-#endif
-  /* count up all classes */
-  class_count = dlink_list_length(class_get_list());
-
-  whowas_count_memory(&wwu, &wwm);
   watch_count_memory(&watch_list_headers, &watch_list_memory);
-
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :WATCH headers %u(%zu) entries %d(%u)",
+                     "z :WATCH headers %u(%zu) entries %u(%u)",
                      watch_list_headers,
                      watch_list_memory, watch_list_entries,
                      watch_list_entries * sizeof(dlink_node) * 2);
@@ -445,14 +391,20 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Resv channels %u(%zu) nicks %u(%zu)",
-                     dlink_list_length(&cresv_items),
-                     dlink_list_length(&cresv_items) * sizeof(struct MaskItem),
-                     dlink_list_length(&nresv_items),
-                     dlink_list_length(&nresv_items) * sizeof(struct MaskItem));
+                     dlink_list_length(resv_chan_get_list()),
+                     dlink_list_length(resv_chan_get_list()) * sizeof(struct ResvItem),
+                     dlink_list_length(resv_nick_get_list()),
+                     dlink_list_length(resv_nick_get_list()) * sizeof(struct ResvItem));
+
+  listener_count_memory(&listener_count, &listener_memory);
+  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
+                     "z :Listeners %u(%zu)",
+                     listener_count, listener_memory);
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Classes %u(%zu)",
-                     class_count, class_count * sizeof(struct ClassItem));
+                     dlink_list_length(class_get_list()),
+                     dlink_list_length(class_get_list()) * sizeof(struct ClassItem));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Channels %u(%zu) Topics %u",
@@ -478,37 +430,22 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
                      channel_invites,
                      channel_invites * sizeof(dlink_node) * 2);
 
-  total_channel_memory = channel_memory + channel_ban_memory +
-                         channel_members * sizeof(struct Membership) +
-                         (channel_invites * sizeof(dlink_node) * 2);
-
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Safelist %u(%zu)",
                      safelist_count, safelist_memory);
 
+  whowas_count_memory(&wwu, &wwm);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :Whowas users %u(%zu)",
-                     wwu, wwu * sizeof(struct Client));
-
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :Whowas array %u(%zu)",
-                     NICKNAMEHISTORYLENGTH, wwm);
-
-  totww = wwu * sizeof(struct Client) + wwm;
+                     "z :Whowas users %u(%zu)", wwu, wwm);
 
   motd_memory_count(source_p);
+
   ipcache_get_stats(&number_ips_stored, &mem_ips_stored);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :iphash %u(%zu)",
                      number_ips_stored, mem_ips_stored);
 
-  total_memory = totww + total_channel_memory + conf_memory + class_count *
-                 sizeof(struct ClassItem);
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :Total: whowas %zu channel %zu conf %zu",
-                     totww, total_channel_memory, conf_memory);
-
-  local_client_memory_used = local_client_count*(sizeof(struct Client) + sizeof(struct Connection));
+  local_client_memory_used = local_client_count *(sizeof(struct Client) + sizeof(struct Connection));
   total_memory += local_client_memory_used;
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Local client Memory in use: %u(%zu)",
@@ -519,11 +456,6 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Remote client Memory in use: %u(%zu)",
                      remote_client_count, remote_client_memory_used);
-
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :TOTAL: %zu",
-                     me.name, RPL_STATSDEBUG, source_p->name,
-                     total_memory);
 }
 
 static void
@@ -540,12 +472,6 @@ stats_dns_servers(struct Client *source_p, int parc, char *parv[])
   }
 }
 
-static void
-stats_connect(struct Client *source_p, int parc, char *parv[])
-{
-  report_confitem_types(source_p, CONF_SERVER);
-}
-
 /* stats_deny()
  *
  * input	- client to report to
@@ -555,7 +481,6 @@ stats_connect(struct Client *source_p, int parc, char *parv[])
 static void
 stats_deny(struct Client *source_p, int parc, char *parv[])
 {
-  const struct MaskItem *conf = NULL;
   const dlink_node *node = NULL;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
@@ -567,8 +492,7 @@ stats_deny(struct Client *source_p, int parc, char *parv[])
       if (arec->type != CONF_DLINE)
         continue;
 
-      conf = arec->conf;
-
+      const struct MaskItem *conf = arec->conf;
       /* Don't report a temporary dline as permanent dline */
       if (conf->until)
         continue;
@@ -587,7 +511,6 @@ stats_deny(struct Client *source_p, int parc, char *parv[])
 static void
 stats_tdeny(struct Client *source_p, int parc, char *parv[])
 {
-  const struct MaskItem *conf = NULL;
   const dlink_node *node = NULL;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
@@ -599,8 +522,7 @@ stats_tdeny(struct Client *source_p, int parc, char *parv[])
       if (arec->type != CONF_DLINE)
         continue;
 
-      conf = arec->conf;
-
+      const struct MaskItem *conf = arec->conf;
       /* Don't report a permanent dline as temporary dline */
       if (!conf->until)
         continue;
@@ -619,7 +541,6 @@ stats_tdeny(struct Client *source_p, int parc, char *parv[])
 static void
 stats_exempt(struct Client *source_p, int parc, char *parv[])
 {
-  const struct MaskItem *conf = NULL;
   const dlink_node *node = NULL;
 
   if (ConfigGeneral.stats_e_disabled)
@@ -637,7 +558,7 @@ stats_exempt(struct Client *source_p, int parc, char *parv[])
       if (arec->type != CONF_EXEMPT)
         continue;
 
-      conf = arec->conf;
+      const struct MaskItem *conf = arec->conf;
       sendto_one_numeric(source_p, &me, RPL_STATSDLINE, 'e', conf->host, "");
     }
   }
@@ -658,31 +579,30 @@ stats_events(struct Client *source_p, int parc, char *parv[])
     const struct event *ev = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                       "E :%-30s %-4d seconds",
-                       ev->name,
-                       (int)(ev->next - CurrentTime));
+                       "E :%-30s %-4ji seconds",
+                       ev->name, ev->next - CurrentTime);
   }
 }
 
 static void
 stats_hubleaf(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL, *dptr = NULL;
+  const dlink_node *node, *node2;
 
-  DLINK_FOREACH(node, server_items.head)
+  DLINK_FOREACH(node, connect_items.head)
   {
     const struct MaskItem *conf = node->data;
 
-    DLINK_FOREACH(dptr, conf->hub_list.head)
-      sendto_one_numeric(source_p, &me, RPL_STATSHLINE, 'H', dptr->data, conf->name, 0, "*");
+    DLINK_FOREACH(node2, conf->hub_list.head)
+      sendto_one_numeric(source_p, &me, RPL_STATSHLINE, 'H', node2->data, conf->name, 0, "*");
   }
 
-  DLINK_FOREACH(node, server_items.head)
+  DLINK_FOREACH(node, connect_items.head)
   {
     const struct MaskItem *conf = node->data;
 
-    DLINK_FOREACH(dptr, conf->leaf_list.head)
-      sendto_one_numeric(source_p, &me, RPL_STATSLLINE, 'L', dptr->data, conf->name, 0, "*");
+    DLINK_FOREACH(node2, conf->leaf_list.head)
+      sendto_one_numeric(source_p, &me, RPL_STATSLLINE, 'L', node2->data, conf->name, 0, "*");
   }
 }
 
@@ -698,43 +618,40 @@ stats_hubleaf(struct Client *source_p, int parc, char *parv[])
 static const char *
 show_iline_prefix(const struct Client *source_p, const struct MaskItem *conf)
 {
-  static char prefix_of_host[USERLEN + 16];
-  char *prefix_ptr = prefix_of_host;
+  static char buf[USERLEN + 16];
+  char *p = buf;
 
   if (IsConfWebIRC(conf))
-    *prefix_ptr++ = '<';
+    *p++ = '<';
   if (IsNoTilde(conf))
-    *prefix_ptr++ = '-';
+    *p++ = '-';
   if (IsNeedIdentd(conf))
-    *prefix_ptr++ = '+';
+    *p++ = '+';
   if (!IsNeedPassword(conf))
-    *prefix_ptr++ = '&';
+    *p++ = '&';
   if (IsConfExemptResv(conf))
-    *prefix_ptr++ = '$';
+    *p++ = '$';
   if (IsConfDoSpoofIp(conf))
-    *prefix_ptr++ = '=';
+    *p++ = '=';
+  if (IsConfCanFlood(conf))
+    *p++ = '|';
   if (HasUMode(source_p, UMODE_OPER))
   {
     if (IsConfExemptKline(conf))
-      *prefix_ptr++ = '^';
+      *p++ = '^';
     if (IsConfExemptXline(conf))
-      *prefix_ptr++ = '!';
+      *p++ = '!';
     if (IsConfExemptLimits(conf))
-      *prefix_ptr++ = '>';
+      *p++ = '>';
   }
 
-  if (IsConfCanFlood(conf))
-    *prefix_ptr++ = '|';
-
-  strlcpy(prefix_ptr, conf->user, USERLEN+1);
-
-  return prefix_of_host;
+  strlcpy(p, conf->user, USERLEN + 1);
+  return buf;
 }
 
 static void
 report_auth(struct Client *source_p, int parc, char *parv[])
 {
-  const struct MaskItem *conf = NULL;
   const dlink_node *node = NULL;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
@@ -746,8 +663,7 @@ report_auth(struct Client *source_p, int parc, char *parv[])
       if (arec->type != CONF_CLIENT)
         continue;
 
-      conf = arec->conf;
-
+      const struct MaskItem *conf = arec->conf;
       if (!HasUMode(source_p, UMODE_OPER) && IsConfDoSpoofIp(conf))
         continue;
 
@@ -782,7 +698,7 @@ stats_auth(struct Client *source_p, int parc, char *parv[])
       conf = find_conf_by_address(source_p->host, NULL, CONF_CLIENT, 0,
                                   source_p->username, NULL, 1);
 
-    if (conf == NULL)
+    if (!conf)
       return;
 
     sendto_one_numeric(source_p, &me, RPL_STATSILINE,
@@ -804,7 +720,6 @@ stats_auth(struct Client *source_p, int parc, char *parv[])
 static void
 report_Klines(struct Client *source_p, int tkline)
 {
-  const struct MaskItem *conf = NULL;
   const dlink_node *node = NULL;
   char c = '\0';
 
@@ -822,8 +737,7 @@ report_Klines(struct Client *source_p, int tkline)
       if (arec->type != CONF_KLINE)
         continue;
 
-      conf = arec->conf;
-
+      const struct MaskItem *conf = arec->conf;
       if ((!tkline && conf->until) ||
           (tkline && !conf->until))
         continue;
@@ -914,15 +828,6 @@ stats_messages(struct Client *source_p, int parc, char *parv[])
     report_messages(source_p);
 }
 
-static void
-stats_oper(struct Client *source_p, int parc, char *parv[])
-{
-  if (!HasUMode(source_p, UMODE_OPER) && ConfigGeneral.stats_o_oper_only)
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
-  else
-    report_confitem_types(source_p, CONF_OPER);
-}
-
 /* stats_operedup()
  *
  * input	- client pointer
@@ -948,7 +853,7 @@ stats_operedup(struct Client *source_p, int parc, char *parv[])
     else
       strlcpy(buf, "n/a", sizeof(buf));
 
-    if (MyClient(source_p) && HasUMode(source_p, UMODE_OPER))
+    if (MyConnect(source_p) && HasUMode(source_p, UMODE_OPER))
       sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                          "p :[%c][%s] %s (%s@%s) Idle: %s",
                          HasUMode(target_p, UMODE_ADMIN) ? 'A' : 'O',
@@ -975,14 +880,13 @@ stats_operedup(struct Client *source_p, int parc, char *parv[])
 static void
 show_ports(struct Client *source_p)
 {
-  char buf[IRCD_BUFSIZE] = "";
-  char *p = NULL;
+  char buf[8] = "";
   const dlink_node *node = NULL;
 
   DLINK_FOREACH(node, listener_get_list()->head)
   {
     const struct Listener *listener = node->data;
-    p = buf;
+    char *p = buf;
 
     if (listener->flags & LISTENER_HIDDEN)
     {
@@ -997,9 +901,8 @@ show_ports(struct Client *source_p)
       *p++ = 's';
     *p = '\0';
 
-
     if (HasUMode(source_p, UMODE_ADMIN) &&
-        (MyClient(source_p) || !ConfigServerHide.hide_server_ips))
+        (MyConnect(source_p) || !ConfigServerHide.hide_server_ips))
       sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
                          listener->name,
                          listener->ref_count, buf,
@@ -1020,18 +923,6 @@ stats_ports(struct Client *source_p, int parc, char *parv[])
     show_ports(source_p);
 }
 
-static void
-stats_resv(struct Client *source_p, int parc, char *parv[])
-{
-  report_resv(source_p);
-}
-
-static void
-stats_service(struct Client *source_p, int parc, char *parv[])
-{
-  report_confitem_types(source_p, CONF_SERVICE);
-}
-
 static void
 stats_tstats(struct Client *source_p, int parc, char *parv[])
 {
@@ -1092,18 +983,16 @@ stats_tstats(struct Client *source_p, int parc, char *parv[])
                      "t :Client Server");
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "t :connected %u %u",
-                     (unsigned int)sp->is_cl,
-                     (unsigned int)sp->is_sv);
+                     sp->is_cl, sp->is_sv);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "t :bytes sent %ju %ju",
                      sp->is_cbs, sp->is_sbs);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "t :bytes recv %ju %ju",
+                     "t :bytes received %ju %ju",
                      sp->is_cbr, sp->is_sbr);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "t :time connected %u %u",
-                     (unsigned int)sp->is_cti,
-                     (unsigned int)sp->is_sti);
+                     "t :time connected %ju %ju",
+                     sp->is_cti, sp->is_sti);
 }
 
 static void
@@ -1124,7 +1013,8 @@ stats_uptime(struct Client *source_p, int parc, char *parv[])
 static void
 stats_shared(struct Client *source_p, int parc, char *parv[])
 {
-  report_confitem_types(source_p, CONF_SHARED);
+  report_shared(source_p);
+  report_cluster(source_p);
 }
 
 /* stats_servers()
@@ -1154,16 +1044,10 @@ stats_servers(struct Client *source_p, int parc, char *parv[])
                      dlink_list_length(&local_server_list));
 }
 
-static void
-stats_gecos(struct Client *source_p, int parc, char *parv[])
-{
-  report_confitem_types(source_p, CONF_XLINE);
-}
-
 static void
 stats_class(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node = NULL;
 
   DLINK_FOREACH(node, class_get_list()->head)
   {
@@ -1184,9 +1068,9 @@ stats_class(struct Client *source_p, int parc, char *parv[])
 static void
 stats_servlinks(struct Client *source_p, int parc, char *parv[])
 {
+  dlink_node *node;
   uintmax_t sendB = 0, recvB = 0;
-  time_t uptime = 0;
-  dlink_node *node = NULL;
+  uintmax_t uptime = 0;
 
   if (ConfigServerHide.flatten_links && !HasUMode(source_p, UMODE_OPER))
   {
@@ -1196,7 +1080,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
 
   DLINK_FOREACH(node, local_server_list.head)
   {
-    struct Client *target_p = node->data;
+    const struct Client *target_p = node->data;
 
     if (HasFlag(target_p, FLAGS_SERVICE) && ConfigServerHide.hide_services)
       if (!HasUMode(source_p, UMODE_OPER))
@@ -1232,14 +1116,14 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "? :Server send: %7.2f %s (%4.1f K/s)",
-                     _GMKv((me.connection->send.bytes>>10)),
-                     _GMKs((me.connection->send.bytes>>10)),
+                     _GMKv((me.connection->send.bytes >> 10)),
+                     _GMKs((me.connection->send.bytes >> 10)),
                      (float)((float)((me.connection->send.bytes) >> 10) /
                      (float)uptime));
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "? :Server recv: %7.2f %s (%4.1f K/s)",
-                     _GMKv((me.connection->recv.bytes>>10)),
-                     _GMKs((me.connection->recv.bytes>>10)),
+                     _GMKv((me.connection->recv.bytes >> 10)),
+                     _GMKs((me.connection->recv.bytes >> 10)),
                      (float)((float)((me.connection->recv.bytes) >> 10) /
                      (float)uptime));
 }
@@ -1279,7 +1163,7 @@ static void
 stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
              dlink_list *list, const char statchar)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   /*
    * Send info about connections which match, or all if the
@@ -1289,7 +1173,7 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
    */
   DLINK_FOREACH(node, list->head)
   {
-    struct Client *target_p = node->data;
+    const struct Client *target_p = node->data;
 
     if (HasUMode(target_p, UMODE_INVISIBLE) && (doall || wilds) &&
         !(MyConnect(source_p) && HasUMode(source_p, UMODE_OPER)) &&
@@ -1306,7 +1190,7 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
      * This basically shows ips for our opers if it's not a server/admin, or
      * it's one of our admins.
      */
-    if (MyClient(source_p) && HasUMode(source_p, UMODE_OPER) &&
+    if (MyConnect(source_p) && HasUMode(source_p, UMODE_OPER) &&
         (HasUMode(source_p, UMODE_ADMIN) ||
         (!IsServer(target_p) && !HasUMode(target_p, UMODE_ADMIN) &&
         !IsHandshake(target_p) && !IsConnecting(target_p))))
@@ -1317,9 +1201,9 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
                  get_client_name(target_p, HIDE_IP),
                  dbuf_length(&target_p->connection->buf_sendq),
                  target_p->connection->send.messages,
-                 target_p->connection->send.bytes>>10,
+                 target_p->connection->send.bytes >> 10,
                  target_p->connection->recv.messages,
-                 target_p->connection->recv.bytes>>10,
+                 target_p->connection->recv.bytes >> 10,
                  (unsigned int)(CurrentTime - target_p->connection->firsttime),
                  (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
                  IsServer(target_p) ? show_capabilities(target_p) : "-");
@@ -1332,9 +1216,9 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
                    get_client_name(target_p, MASK_IP),
                    dbuf_length(&target_p->connection->buf_sendq),
                    target_p->connection->send.messages,
-                   target_p->connection->send.bytes>>10,
+                   target_p->connection->send.bytes >> 10,
                    target_p->connection->recv.messages,
-                   target_p->connection->recv.bytes>>10,
+                   target_p->connection->recv.bytes >> 10,
                    (unsigned int)(CurrentTime - target_p->connection->firsttime),
                    (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since):0,
                    IsServer(target_p) ? show_capabilities(target_p) : "-");
@@ -1345,9 +1229,9 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
                    get_client_name(target_p, HIDE_IP),
                    dbuf_length(&target_p->connection->buf_sendq),
                    target_p->connection->send.messages,
-                   target_p->connection->send.bytes>>10,
+                   target_p->connection->send.bytes >> 10,
                    target_p->connection->recv.messages,
-                   target_p->connection->recv.bytes>>10,
+                   target_p->connection->recv.bytes >> 10,
                    (unsigned int)(CurrentTime - target_p->connection->firsttime),
                    (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since):0,
                    IsServer(target_p) ? show_capabilities(target_p) : "-");
@@ -1419,14 +1303,12 @@ static const struct StatsStruct  stats_tab[] =
   { 'L',  stats_ltrace,      UMODE_OPER  },
   { 'm',  stats_messages,    0           },
   { 'M',  stats_messages,    0           },
-  { 'o',  stats_oper,        0           },
-  { 'O',  stats_oper,        0           },
+  { 'o',  stats_operator,    0           },
+  { 'O',  stats_operator,    0           },
   { 'p',  stats_operedup,    0           },
   { 'P',  stats_ports,       0           },
   { 'q',  stats_resv,        UMODE_OPER  },
   { 'Q',  stats_resv,        UMODE_OPER  },
-  { 'r',  stats_usage,       UMODE_OPER  },
-  { 'R',  stats_usage,       UMODE_OPER  },
   { 's',  stats_service,     UMODE_OPER  },
   { 'S',  stats_service,     UMODE_OPER  },
   { 't',  stats_tstats,      UMODE_OPER  },
@@ -1480,7 +1362,7 @@ do_stats(struct Client *source_p, int parc, char *parv[])
 static int
 m_stats(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   /* Check the user is actually allowed to do /stats, and isn't flooding */
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
@@ -1550,7 +1432,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7510 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
