@@ -21,7 +21,7 @@
 
 /*! \file m_svinfo.c
  * \brief Includes required functions for processing the SVINFO command.
- * \version $Id: m_svinfo.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_svinfo.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -89,13 +89,13 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   if (deltat > ConfigGeneral.ts_max_delta)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
          get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
           get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
     ilog(LOG_TYPE_IRCD,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
          get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
 
     exit_client(source_p, "Excessive TS delta");
@@ -105,10 +105,10 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   if (deltat > ConfigGeneral.ts_warn_delta)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
           get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
           get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
   }
 
@@ -141,7 +141,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
