@@ -22,7 +22,7 @@
 
 /*! \file m_svsnick.c
  * \brief Includes required functions for processing the SVSNICK command.
- * \version $Id: m_svsnick.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_svsnick.c 7468 2016-03-12 19:06:56Z michael $
  */
 
 
@@ -58,7 +58,10 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL, *exists_p = NULL;
 
-  if (!HasFlag(source_p, FLAGS_SERVICE) || !valid_nickname(parv[2], 1))
+  if (!HasFlag(source_p, FLAGS_SERVICE))
+    return 0;
+
+  if (!valid_nickname(parv[2], 1))
     return 0;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
@@ -97,7 +100,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  target_p->tsinfo = strtoimax(parv[3], NULL, 10);
+  target_p->tsinfo = strtoumax(parv[3], NULL, 10);
   clear_ban_cache_client(target_p);
   watch_check_hash(target_p, RPL_LOGOFF);
 
@@ -154,7 +157,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7468 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
