@@ -21,20 +21,16 @@
 
 /*! \file m_svstag.c
  * \brief Includes required functions for processing the SVSTAG command.
- * \version $Id: m_svstag.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_svstag.c 7372 2016-02-28 17:02:08Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
 #include "send.h"
-#include "channel_mode.h"
 #include "parse.h"
-#include "memory.h"
 #include "modules.h"
 #include "irc_string.h"
-#include "user.h"
-#include "conf.h"
 
 
 /*! \brief SVSTAG command handler
@@ -56,7 +52,6 @@ static int
 ms_svstag(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
-  time_t ts = 0;
 
   if (!HasFlag(source_p, FLAGS_SERVICE) && !IsServer(source_p))
     return 0;
@@ -64,7 +59,7 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
   if ((target_p = find_person(source_p, parv[1])) == NULL)
     return 0;
 
-  ts = strtoimax(parv[2], NULL, 10);
+  uintmax_t ts = strtoimax(parv[2], NULL, 10);
   if (ts && (ts != target_p->tsinfo))
     return 0;
 
@@ -117,7 +112,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7372 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
