@@ -21,7 +21,7 @@
 
 /*! \file m_unkline.c
  * \brief Includes required functions for processing the UNKLINE command.
- * \version $Id: m_unkline.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_unkline.c 7428 2016-03-07 17:46:09Z michael $
  */
 
 #include "stdinc.h"
@@ -30,6 +30,8 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_shared.h"
 #include "hostmask.h"
 #include "numeric.h"
 #include "log.h"
@@ -127,7 +129,7 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNKLINE", source_p, parc, parv, 0, &user,
+  if (!parse_aline("UNKLINE", source_p, parc, parv, &user,
                    &host, NULL, &target_server, NULL))
     return 0;
 
@@ -142,8 +144,8 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNKLINE", CAPAB_UNKLN, SHARED_UNKLINE,
-                   "%s %s", user, host);
+    cluster_distribute(source_p, "UNKLINE", CAPAB_UNKLN, CLUSTER_UNKLINE,
+                       "%s %s", user, host);
 
   kline_remove_and_notify(source_p, user, host);
   return 0;
@@ -158,7 +160,7 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *      - parv[0] = command
- *      - parv[1] = target server
+ *      - parv[1] = target server mask
  *      - parv[2] = user mask
  *      - parv[3] = host mask
  */
@@ -180,9 +182,8 @@ ms_unkline(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_UNKLINE))
+      shared_find(SHARED_UNKLINE, source_p->servptr->name,
+                  source_p->username, source_p->host))
     kline_remove_and_notify(source_p, user, host);
 
   return 0;
@@ -216,7 +217,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7428 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
