@@ -21,7 +21,7 @@
 
 /*! \file m_version.c
  * \brief Includes required functions for processing the VERSION command.
- * \version $Id: m_version.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_version.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -66,7 +66,7 @@ static const char serveropts[] =
 static int
 m_version(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
   {
@@ -134,7 +134,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
