@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_who.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -148,7 +148,7 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
 {
   dlink_node *node = NULL;
   unsigned int maxmatches = WHO_MAX_REPLIES;
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if (!HasUMode(source_p, UMODE_OPER))
   {
@@ -357,7 +357,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
