@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_whowas.c 7448 2016-03-11 17:21:27Z michael $
  */
 
 #include "stdinc.h"
@@ -55,7 +55,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
   if (!MyConnect(source_p) && (max <= 0 || max > WHOWAS_MAX_REPLIES))
     max = WHOWAS_MAX_REPLIES;
 
-  DLINK_FOREACH(node, WHOWASHASH[strhash(parv[1])].head)
+  DLINK_FOREACH(node, whowas_get_hash(strhash(parv[1]))->head)
   {
     const struct Whowas *whowas = node->data;
 
@@ -108,7 +108,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
 static int
 m_whowas(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -186,7 +186,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7448 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
