@@ -21,7 +21,7 @@
 
 /*! \file m_xline.c
  * \brief Includes required functions for processing the XLINE command.
- * \version $Id: m_xline.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_xline.c 7434 2016-03-09 17:49:48Z michael $
  */
 
 #include "stdinc.h"
@@ -30,6 +30,9 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_gecos.h"
+#include "conf_shared.h"
 #include "numeric.h"
 #include "log.h"
 #include "misc.h"
@@ -41,7 +44,7 @@
 
 
 static void
-xline_check(struct MaskItem *conf)
+xline_check(const struct GecosItem *gecos)
 {
   dlink_node *node = NULL, *node_next = NULL;
 
@@ -52,43 +55,42 @@ xline_check(struct MaskItem *conf)
     if (IsDead(client_p))
       continue;
 
-    if (!match(conf->name, client_p->info))
-      conf_try_ban(client_p, conf);
+    if (!match(gecos->mask, client_p->info))
+      conf_try_ban(client_p, CLIENT_BAN_XLINE, gecos->reason);
   }
 }
 
-/* valid_xline()
- *
- * inputs       - client to complain to, gecos, reason, whether to complain
- * outputs      - 1 for valid, else 0
- * side effects - complains to client, when warn != 0
- */
-static int
-valid_xline(struct Client *source_p, const char *gecos)
-{
-  if (!valid_wild_card_simple(gecos))
-  {
-    if (IsClient(source_p))
-      sendto_one_notice(source_p, &me, ":Please include at least %u non-wildcard characters with the xline",
-                        ConfigGeneral.min_nonwildcard_simple);
-    return 0;
-  }
-
-  return 1;
-}
-
-/* xline_add()
+/* xline_handle()
  *
  * inputs       - client taking credit for xline, gecos, reason, xline type
  * outputs      - none
  * side effects - when successful, adds an xline to the conf
  */
 static void
-xline_add(struct Client *source_p, const char *gecos, const char *reason,
-          time_t duration)
+xline_handle(struct Client *source_p, const char *mask, const char *reason,
+             uintmax_t duration)
 {
   char buf[IRCD_BUFSIZE];
-  struct MaskItem *conf;
+  struct GecosItem *gecos = NULL;
+
+  if (!HasFlag(source_p, FLAGS_SERVICE))
+  {
+    if (!valid_wild_card_simple(mask))
+    {
+      if (IsClient(source_p))
+        sendto_one_notice(source_p, &me, ":Please include at least %u non-wildcard characters with the xline",
+                          ConfigGeneral.min_nonwildcard_simple);
+      return;
+    }
+  }
+
+  if ((gecos = gecos_find(mask, match)))
+  {
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":[%s] already X-Lined by [%s] - %s",
+                        mask, gecos->mask, gecos->reason);
+    return;
+  }
 
   if (duration)
     snprintf(buf, sizeof(buf), "Temporary X-line %ju min. - %.*s (%s)",
@@ -96,63 +98,42 @@ xline_add(struct Client *source_p, const char *gecos, const char *reason,
   else
     snprintf(buf, sizeof(buf), "%.*s (%s)", REASONLEN, reason, date_iso8601(0));
 
-  conf = conf_make(CONF_XLINE);
-  conf->name = xstrdup(gecos);
-  conf->reason = xstrdup(buf);
-  conf->setat = CurrentTime;
-  SetConfDatabase(conf);
+  gecos = gecos_make();
+  gecos->mask = xstrdup(mask);
+  gecos->reason = xstrdup(buf);
+  gecos->setat = CurrentTime;
+  gecos->in_database = 1;
 
   if (duration)
   {
-    conf->until = CurrentTime + duration;
+    gecos->expire = CurrentTime + duration;
 
     if (IsClient(source_p))
       sendto_one_notice(source_p, &me, ":Added temporary %ju min. X-Line [%s]",
-                        duration / 60, conf->name);
+                        duration / 60, gecos->mask);
 
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s added temporary %ju min. X-Line for [%s] [%s]",
                          get_oper_name(source_p), duration / 60,
-                         conf->name, conf->reason);
+                         gecos->mask, gecos->reason);
     ilog(LOG_TYPE_XLINE, "%s added temporary %ju min. X-Line for [%s] [%s]",
-         get_oper_name(source_p), duration / 60, conf->name, conf->reason);
+         get_oper_name(source_p), duration / 60, gecos->mask, gecos->reason);
   }
   else
   {
     if (IsClient(source_p))
       sendto_one_notice(source_p, &me, ":Added X-Line [%s] [%s]",
-                        conf->name, conf->reason);
+                        gecos->mask, gecos->reason);
 
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s added X-Line for [%s] [%s]",
-                         get_oper_name(source_p), conf->name,
-                         conf->reason);
+                         get_oper_name(source_p), gecos->mask,
+                         gecos->reason);
     ilog(LOG_TYPE_XLINE, "%s added X-Line for [%s] [%s]",
-         get_oper_name(source_p), conf->name, conf->reason);
+         get_oper_name(source_p), gecos->mask, gecos->reason);
   }
 
-  xline_check(conf);
-}
-
-static void
-relay_xline(struct Client *source_p, char *parv[])
-{
-  struct MaskItem *conf = NULL;
-
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_XLINE))
-  {
-    if ((conf = find_matching_name_conf(CONF_XLINE, parv[2], NULL, NULL, 0)))
-    {
-      if (IsClient(source_p))
-        sendto_one_notice(source_p, &me, ":[%s] already X-Lined by [%s] - %s",
-                          parv[2], conf->name, conf->reason);
-      return;
-    }
-
-    xline_add(source_p, parv[2], parv[4], atoi(parv[3]));
-  }
+  xline_check(gecos);
 }
 
 /* mo_xline()
@@ -169,10 +150,9 @@ static int
 mo_xline(struct Client *source_p, int parc, char *parv[])
 {
   char *reason = NULL;
-  char *gecos = NULL;
-  struct MaskItem *conf = NULL;
+  char *mask = NULL;
   char *target_server = NULL;
-  time_t duration = 0;
+  uintmax_t duration = 0;
 
   if (!HasOFlag(source_p, OPER_FLAG_XLINE))
   {
@@ -180,34 +160,24 @@ mo_xline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("XLINE", source_p, parc, parv, 0, &gecos, NULL,
+  if (!parse_aline("XLINE", source_p, parc, parv, &mask, NULL,
                    &duration, &target_server, &reason))
     return 0;
 
   if (target_server)
   {
     sendto_match_servs(source_p, target_server, CAPAB_CLUSTER, "XLINE %s %s %ju :%s",
-                       target_server, gecos, duration, reason);
+                       target_server, mask, duration, reason);
 
     /* Allow ON to apply local xline as well if it matches */
     if (match(target_server, me.name))
       return 0;
   }
   else
-    cluster_a_line(source_p, "XLINE", CAPAB_CLUSTER, SHARED_XLINE, "%s %ju :%s",
-                   gecos, duration, reason);
+    cluster_distribute(source_p, "XLINE", CAPAB_CLUSTER, CLUSTER_XLINE, "%s %ju :%s",
+                       mask, duration, reason);
 
-  if (!valid_xline(source_p, gecos))
-    return 0;
-
-  if ((conf = find_matching_name_conf(CONF_XLINE, gecos, NULL, NULL, 0)))
-  {
-    sendto_one_notice(source_p, &me, ":[%s] already X-Lined by [%s] - %s",
-                      gecos, conf->name, conf->reason);
-    return 0;
-  }
-
-  xline_add(source_p, gecos, reason, duration);
+  xline_handle(source_p, mask, reason, duration);
   return 0;
 }
 
@@ -220,9 +190,9 @@ mo_xline(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *      - parv[0] = command
- *      - parv[1] = target server
+ *      - parv[1] = target server mask
  *      - parv[2] = gecos
- *      - parv[3] = time
+ *      - parv[3] = duration in seconds
  *      - parv[4] = reason
  */
 static int
@@ -237,10 +207,11 @@ ms_xline(struct Client *source_p, int parc, char *parv[])
   if (match(parv[1], me.name))
     return 0;
 
-  if (!valid_xline(source_p, parv[2]))
-    return 0;
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      shared_find(SHARED_XLINE, source_p->servptr->name,
+                  source_p->username, source_p->host))
+    xline_handle(source_p, parv[2], parv[4], strtoumax(parv[3], NULL, 10));
 
-  relay_xline(source_p, parv);
   return 0;
 }
 
@@ -270,7 +241,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7434 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
