@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 7011 2016-01-01 13:52:10Z michael $
+ * \version $Id: channel.c 7543 2016-04-21 11:15:58Z michael $
  */
 
 #include "stdinc.h"
@@ -31,6 +31,7 @@
 #include "client.h"
 #include "hash.h"
 #include "conf.h"
+#include "conf_resv.h"
 #include "hostmask.h"
 #include "irc_string.h"
 #include "ircd.h"
@@ -41,7 +42,6 @@
 #include "memory.h"
 #include "mempool.h"
 #include "misc.h"
-#include "resv.h"
 
 
 dlink_list channel_list;
@@ -74,8 +74,6 @@ void
 add_user_to_channel(struct Channel *chptr, struct Client *client_p,
                     unsigned int flags, int flood_ctrl)
 {
-  struct Membership *member = NULL;
-
   assert(IsClient(client_p));
 
   if (GlobalSetOptions.joinfloodtime > 0)
@@ -109,7 +107,7 @@ add_user_to_channel(struct Channel *chptr, struct Client *client_p,
     chptr->last_join_time = CurrentTime;
   }
 
-  member = mp_pool_get(member_pool);
+  struct Membership *member = mp_pool_get(member_pool);
   member->client_p = client_p;
   member->chptr = chptr;
   member->flags = flags;
@@ -322,10 +320,11 @@ remove_ban(struct Ban *ban, dlink_list *list)
 static void
 channel_free_mask_list(dlink_list *list)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, list->head)
-    remove_ban(node->data, list);
+  while (list->head)
+  {
+    struct Ban *ban = list->head->data;
+    remove_ban(ban, list);
+  }
 }
 
 /*! \brief Get Channel block for name (and allocate a new channel
@@ -482,11 +481,9 @@ add_invite(struct Channel *chptr, struct Client *client_p)
 
   del_invite(chptr, client_p);
 
-  /*
-   * Delete last link in chain if the list is max length
-   */
-  if (dlink_list_length(&client_p->connection->invited) >=
-      ConfigChannel.max_channels)
+  /* Delete last link in chain if the list is max length */
+  while (dlink_list_length(&client_p->connection->invited) && 
+         dlink_list_length(&client_p->connection->invited) >= ConfigChannel.max_channels)
     del_invite(client_p->connection->invited.tail->data, client_p);
 
   /* Add client to channel invite list */
@@ -581,7 +578,7 @@ get_member_status(const struct Membership *member, const int combine)
  * \return 1 if ban found for given n!u\@h mask, 0 otherwise
  */
 static int
-find_bmask(const struct Client *client_p, const dlink_list *const list)
+find_bmask(const struct Client *client_p, const dlink_list *list)
 {
   const dlink_node *node = NULL;
 
@@ -742,14 +739,14 @@ int
 can_send(struct Channel *chptr, struct Client *client_p,
          struct Membership *member, const char *message, int notice)
 {
-  const struct MaskItem *conf = NULL;
+  const struct ResvItem *resv = NULL;
 
   if (IsServer(client_p) || HasFlag(client_p, FLAGS_SERVICE))
     return CAN_SEND_OPV;
 
-  if (MyClient(client_p) && !HasFlag(client_p, FLAGS_EXEMPTRESV))
+  if (MyConnect(client_p) && !HasFlag(client_p, FLAGS_EXEMPTRESV))
     if (!(HasUMode(client_p, UMODE_OPER) && HasOFlag(client_p, OPER_FLAG_JOIN_RESV)))
-      if ((conf = match_find_resv(chptr->name)) && !resv_find_exempt(client_p, conf))
+      if ((resv = resv_find(chptr->name, match)) && !resv_exempt_find(client_p, resv))
         return ERR_CANNOTSENDTOCHAN;
 
   if ((chptr->mode.mode & MODE_NOCTRL) && msg_has_ctrls(message))
@@ -776,7 +773,7 @@ can_send(struct Channel *chptr, struct Client *client_p,
     return ERR_CANNOTSENDTOCHAN;
 
   /* Cache can send if banned */
-  if (MyClient(client_p))
+  if (MyConnect(client_p))
   {
     if (member)
     {
@@ -873,7 +870,7 @@ check_spambot_warning(struct Client *client_p, const char *name)
  */
 void
 channel_set_topic(struct Channel *chptr, const char *topic,
-                  const char *topic_info, time_t topicts, int local)
+                  const char *topic_info, uintmax_t topicts, int local)
 {
   if (local)
     strlcpy(chptr->topic, topic, IRCD_MIN(sizeof(chptr->topic), ConfigServerInfo.max_topic_length + 1));
@@ -896,23 +893,21 @@ channel_set_topic(struct Channel *chptr, const char *topic,
 void
 channel_do_join_0(struct Client *client_p)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
   if (client_p->channel.head)
     if (MyConnect(client_p) && !HasUMode(client_p, UMODE_OPER))
       check_spambot_warning(client_p, NULL);
 
-  DLINK_FOREACH_SAFE(node, node_next, client_p->channel.head)
+  while (client_p->channel.head)
   {
-    struct Channel *chptr = ((struct Membership *)node->data)->chptr;
+    struct Membership *member = client_p->channel.head->data;
 
     sendto_server(client_p, 0, 0, ":%s PART %s",
-                  client_p->id, chptr->name);
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s PART %s",
+                  client_p->id, member->chptr->name);
+    sendto_channel_local(NULL, member->chptr, 0, 0, 0, ":%s!%s@%s PART %s",
                          client_p->name, client_p->username,
-                         client_p->host, chptr->name);
+                         client_p->host, member->chptr->name);
 
-    remove_user_from_channel(node->data);
+    remove_user_from_channel(member);
   }
 }
 
@@ -951,10 +946,9 @@ void
 channel_do_join(struct Client *client_p, char *channel, char *key_list)
 {
   char *p = NULL;
-  char *chan = NULL;
   char *chan_list = NULL;
   struct Channel *chptr = NULL;
-  struct MaskItem *conf = NULL;
+  const struct ResvItem *resv = NULL;
   const struct ClassItem *const class = get_class_ptr(&client_p->connection->confs);
   int i = 0;
   unsigned int flags = 0;
@@ -963,8 +957,8 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
 
   chan_list = channel_find_last0(client_p, channel);
 
-  for (chan = strtok_r(chan_list, ",", &p); chan;
-       chan = strtok_r(NULL,      ",", &p))
+  for (const char *chan = strtok_r(chan_list, ",", &p); chan;
+                   chan = strtok_r(NULL,      ",", &p))
   {
     const char *key = NULL;
 
@@ -984,10 +978,9 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
 
     if (!HasFlag(client_p, FLAGS_EXEMPTRESV) &&
         !(HasUMode(client_p, UMODE_OPER) && HasOFlag(client_p, OPER_FLAG_JOIN_RESV)) &&
-        ((conf = match_find_resv(chan)) && !resv_find_exempt(client_p, conf)))
+        ((resv = resv_find(chan, match)) && !resv_exempt_find(client_p, resv)))
     {
-      ++conf->count;
-      sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, chan, conf->reason);
+      sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, chan, resv->reason);
       sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                            "Forbidding reserved channel %s from user %s",
                            chan, get_client_name(client_p, HIDE_IP));
