@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: client.c 7487 2016-03-16 15:31:44Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,7 @@
 #include "auth.h"
 #include "s_bsd.h"
 #include "conf.h"
+#include "conf_gecos.h"
 #include "log.h"
 #include "misc.h"
 #include "server.h"
@@ -124,7 +125,7 @@ free_client(struct Client *client_p)
   assert(client_p->idhnext == client_p);
   assert(client_p->channel.head == NULL);
   assert(dlink_list_length(&client_p->channel) == 0);
-  assert(dlink_list_length(&client_p->whowas) == 0);
+  assert(dlink_list_length(&client_p->whowas_list) == 0);
   assert(dlink_list_length(&client_p->svstags) == 0);
 
   xfree(client_p->serv);
@@ -157,15 +158,14 @@ free_client(struct Client *client_p)
 
 void
 client_attach_svstag(struct Client *client_p, unsigned int numeric,
-                     const char *umodes, const char *const tag)
+                     const char *umodes, const char *tag)
 {
-  struct ServicesTag *svstag = NULL;
   const struct user_modes *tab = NULL;
 
   if (numeric >= ERR_LAST_ERR_MSG || *umodes != '+')
     return;
 
-  svstag = xcalloc(sizeof(*svstag));
+  struct ServicesTag *svstag = xcalloc(sizeof(*svstag));
   svstag->numeric = numeric;
   svstag->tag = xstrdup(tag);
 
@@ -182,11 +182,9 @@ client_attach_svstag(struct Client *client_p, unsigned int numeric,
 void
 client_clear_svstags(struct Client *client_p)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, client_p->svstags.head)
+  while (client_p->svstags.head)
   {
-    struct ServicesTag *svstag = node->data;
+    struct ServicesTag *svstag = client_p->svstags.head->data;
 
     dlinkDelete(&svstag->node, &client_p->svstags);
     xfree(svstag->tag);
@@ -204,7 +202,7 @@ static void
 check_pings_list(dlink_list *list)
 {
   char buf[32] = "";  /* 32 = sizeof("Ping timeout: 999999999 seconds") */
-  int ping = 0;      /* ping time value from client */
+  unsigned int ping = 0;      /* ping time value from client */
   dlink_node *node = NULL, *node_next = NULL;
 
   DLINK_FOREACH_SAFE(node, node_next, list->head)
@@ -290,7 +288,6 @@ check_unknowns_list(void)
  * kill off stuff that should die
  *
  * inputs       - NOT USED (from event)
- * output       - next time_t when check_pings() should be called again
  * side effects -
  *
  *
@@ -329,8 +326,8 @@ check_pings(void *unused)
 void
 check_conf_klines(void)
 {
-  struct MaskItem *conf = NULL;
   dlink_node *node = NULL, *node_next = NULL;
+  const void *ptr;
 
   DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
@@ -340,25 +337,27 @@ check_conf_klines(void)
     if (IsDead(client_p))
       continue;
 
-    if ((conf = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
-                                     client_p->connection->aftype, NULL, NULL, 1)))
+    if ((ptr = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
+                                    client_p->connection->aftype, NULL, NULL, 1)))
     {
-      conf_try_ban(client_p, conf);
+      const struct MaskItem *conf = ptr;
+      conf_try_ban(client_p, CLIENT_BAN_DLINE, conf->reason);
       continue;  /* and go examine next Client */
     }
 
-    if ((conf = find_conf_by_address(client_p->host, &client_p->connection->ip,
-                                     CONF_KLINE, client_p->connection->aftype,
-                                     client_p->username, NULL, 1)))
+    if ((ptr = find_conf_by_address(client_p->host, &client_p->connection->ip,
+                                    CONF_KLINE, client_p->connection->aftype,
+                                    client_p->username, NULL, 1)))
     {
-      conf_try_ban(client_p, conf);
+      const struct MaskItem *conf = ptr;
+      conf_try_ban(client_p, CLIENT_BAN_KLINE, conf->reason);
       continue;  /* and go examine next Client */
     }
 
-    if ((conf = find_matching_name_conf(CONF_XLINE, client_p->info,
-                                        NULL, NULL, 0)))
+    if ((ptr = gecos_find(client_p->info, match)))
     {
-      conf_try_ban(client_p, conf);
+      const struct GecosItem *conf = ptr;
+      conf_try_ban(client_p, CLIENT_BAN_XLINE, conf->reason);
       continue;  /* and go examine next Client */
     }
   }
@@ -368,10 +367,11 @@ check_conf_klines(void)
   {
     struct Client *client_p = node->data;
 
-    if ((conf = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
-                                     client_p->connection->aftype, NULL, NULL, 1)))
+    if ((ptr = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
+                                    client_p->connection->aftype, NULL, NULL, 1)))
     {
-      conf_try_ban(client_p, conf);
+      const struct MaskItem *conf = ptr;
+      conf_try_ban(client_p, CLIENT_BAN_DLINE, conf->reason);
       continue;  /* and go examine next Client */
     }
   }
@@ -386,13 +386,13 @@ check_conf_klines(void)
  * side effects	- given client_p is banned
  */
 void
-conf_try_ban(struct Client *client_p, struct MaskItem *conf)
+conf_try_ban(struct Client *client_p, int type, const char *reason)
 {
   char ban_type = '?';
 
-  switch (conf->type)
+  switch (type)
   {
-    case CONF_KLINE:
+    case CLIENT_BAN_KLINE:
       if (HasFlag(client_p, FLAGS_EXEMPTKLINE))
       {
         sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
@@ -403,13 +403,13 @@ conf_try_ban(struct Client *client_p, struct MaskItem *conf)
 
       ban_type = 'K';
       break;
-    case CONF_DLINE:
+    case CLIENT_BAN_DLINE:
       if (find_conf_by_address(NULL, &client_p->connection->ip, CONF_EXEMPT,
                                client_p->connection->aftype, NULL, NULL, 1))
         return;
       ban_type = 'D';
       break;
-    case CONF_XLINE:
+    case CLIENT_BAN_XLINE:
       if (HasFlag(client_p, FLAGS_EXEMPTXLINE))
       {
         sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
@@ -419,7 +419,6 @@ conf_try_ban(struct Client *client_p, struct MaskItem *conf)
       }
 
       ban_type = 'X';
-      ++conf->count;
       break;
     default:
       assert(0);
@@ -430,9 +429,9 @@ conf_try_ban(struct Client *client_p, struct MaskItem *conf)
                        ban_type, get_client_name(client_p, HIDE_IP));
 
   if (IsClient(client_p))
-    sendto_one_numeric(client_p, &me, ERR_YOUREBANNEDCREEP, conf->reason);
+    sendto_one_numeric(client_p, &me, ERR_YOUREBANNEDCREEP, reason);
 
-  exit_client(client_p, conf->reason);
+  exit_client(client_p, reason);
 }
 
 /* update_client_exit_stats()
@@ -467,7 +466,7 @@ update_client_exit_stats(struct Client *client_p)
  * side effects - find person by (nick)name
  */
 struct Client *
-find_person(const struct Client *const source_p, const char *name)
+find_person(const struct Client *source_p, const char *name)
 {
   struct Client *target_p = NULL;
 
@@ -498,7 +497,7 @@ find_chasing(struct Client *source_p, const char *name)
   if (IsDigit(*name))
     return NULL;
 
-  target_p = whowas_get_history(name, (time_t)ConfigGeneral.kill_chase_time_limit);
+  target_p = whowas_get_history(name, ConfigGeneral.kill_chase_time_limit);
 
   if (!target_p)
   {
@@ -721,8 +720,6 @@ exit_client(struct Client *source_p, const char *comment)
 
     if (IsClient(source_p))
     {
-      time_t on_for = CurrentTime - source_p->connection->firsttime;
-
       assert(Count.local > 0);
 
       --Count.local;
@@ -744,12 +741,13 @@ exit_client(struct Client *source_p, const char *comment)
                            source_p->name, source_p->username, source_p->host,
                            source_p->sockhost, comment);
 
-      ilog(LOG_TYPE_USER, "%s (%3u:%02u:%02u): %s!%s@%s %ju/%ju",
-           date_ctime(source_p->connection->firsttime), (unsigned int)(on_for / 3600),
-           (unsigned int)((on_for % 3600)/60), (unsigned int)(on_for % 60),
+      ilog(LOG_TYPE_USER, "%s (%ju): %s!%s@%s %s %s %ju/%ju :%s",
+           date_ctime(source_p->connection->firsttime),
+           CurrentTime - source_p->connection->firsttime,
            source_p->name, source_p->username, source_p->host,
-           source_p->connection->send.bytes>>10,
-           source_p->connection->recv.bytes>>10);
+           source_p->sockhost, source_p->account,
+           source_p->connection->send.bytes >> 10,
+           source_p->connection->recv.bytes >> 10, source_p->info);
     }
     else if (IsServer(source_p))
     {
