@@ -21,16 +21,20 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: conf.c 7536 2016-04-11 15:02:36Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
 #include "ircd_defs.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_gecos.h"
 #include "conf_pseudo.h"
+#include "conf_resv.h"
+#include "conf_service.h"
+#include "conf_shared.h"
 #include "server.h"
-#include "resv.h"
 #include "channel.h"
 #include "client.h"
 #include "event.h"
@@ -56,6 +60,7 @@
 #include "motd.h"
 #include "ipcache.h"
 #include "isupport.h"
+#include "whowas.h"
 
 
 struct config_channel_entry ConfigChannel;
@@ -67,14 +72,8 @@ struct config_admin_entry ConfigAdminInfo;
 struct conf_parser_context conf_parser_ctx;
 
 /* general conf items link list root, other than k lines etc. */
-dlink_list service_items;
-dlink_list server_items;
-dlink_list cluster_items;
+dlink_list connect_items;
 dlink_list operator_items;
-dlink_list shared_items;
-dlink_list gecos_items;
-dlink_list nresv_items;
-dlink_list cresv_items;
 
 extern unsigned int lineno;
 extern char linebuf[];
@@ -136,29 +135,11 @@ map_to_list(enum maskitem_type type)
 {
   switch (type)
   {
-    case CONF_XLINE:
-      return &gecos_items;
-      break;
-    case CONF_SHARED:
-      return &shared_items;
-      break;
-    case CONF_NRESV:
-      return &nresv_items;
-      break;
-    case CONF_CRESV:
-      return &cresv_items;
-      break;
     case CONF_OPER:
       return &operator_items;
       break;
     case CONF_SERVER:
-      return &server_items;
-      break;
-    case CONF_SERVICE:
-      return &service_items;
-      break;
-    case CONF_CLUSTER:
-      return &cluster_items;
+      return &connect_items;
       break;
     default:
       return NULL;
@@ -207,12 +188,8 @@ conf_free(struct MaskItem *conf)
   xfree(conf->whois);
   xfree(conf->user);
   xfree(conf->host);
-#ifdef HAVE_LIBCRYPTO
   xfree(conf->cipher_list);
 
-  if (conf->rsa_public_key)
-    RSA_free(conf->rsa_public_key);
-#endif
   DLINK_FOREACH_SAFE(node, node_next, conf->hub_list.head)
   {
     xfree(node->data);
@@ -227,17 +204,6 @@ conf_free(struct MaskItem *conf)
     free_dlink_node(node);
   }
 
-  DLINK_FOREACH_SAFE(node, node_next, conf->exempt_list.head)
-  {
-    struct exempt *exptr = node->data;
-
-    dlinkDelete(node, &conf->exempt_list);
-    xfree(exptr->name);
-    xfree(exptr->user);
-    xfree(exptr->host);
-    xfree(exptr);
-  }
-
   xfree(conf);
 }
 
@@ -401,9 +367,8 @@ check_client(struct Client *source_p)
       /* jdc - lists server name & port connections are on */
       /*       a purely cosmetical change */
       sendto_realops_flags(UMODE_UNAUTH, L_ALL, SEND_NOTICE,
-                           "Unauthorized client connection from %s [%s] on [%s/%u].",
+                           "Unauthorized client connection from %s on [%s/%u].",
                            get_client_name(source_p, SHOW_IP),
-                           source_p->sockhost,
                            source_p->connection->listener->name,
                            source_p->connection->listener->port);
       ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s on [%s/%u].",
@@ -514,11 +479,12 @@ attach_connect_block(struct Client *client_p, const char *name,
 
   assert(host);
 
-  DLINK_FOREACH(node, server_items.head)
+  DLINK_FOREACH(node, connect_items.head)
   {
     struct MaskItem *conf = node->data;
 
-    if (match(conf->name, name) || match(conf->host, host))
+    if (irccmp(conf->name, name) ||
+        irccmp(conf->host, host))
       continue;
 
     attach_conf(client_p, conf);
@@ -567,66 +533,20 @@ find_conf_name(dlink_list *list, const char *name, enum maskitem_type type)
  * side effects - looks for a match on name field
  */
 struct MaskItem *
-find_matching_name_conf(enum maskitem_type type, const char *name, const char *user,
-                        const char *host, unsigned int flags)
+connect_find(const char *name, const char *host, int (*compare)(const char *, const char *))
 {
   dlink_node *node = NULL;
-  dlink_list *list = map_to_list(type);
-  struct MaskItem *conf = NULL;
 
-  switch (type)
+  DLINK_FOREACH(node, connect_items.head)
   {
-  case CONF_SERVICE:
-    DLINK_FOREACH(node, list->head)
-    {
-      conf = node->data;
+    struct MaskItem *conf = node->data;
 
-      if (EmptyString(conf->name))
-        continue;
-      if (name && !irccmp(name, conf->name))
-        return conf;
-    }
-    break;
-
-  case CONF_XLINE:
-  case CONF_SHARED:
-  case CONF_NRESV:
-  case CONF_CRESV:
-    DLINK_FOREACH(node, list->head)
-    {
-      conf = node->data;
-
-      if (EmptyString(conf->name))
-        continue;
-      if (name && !match(conf->name, name))
-      {
-        if ((user == NULL && (host == NULL)))
-          return conf;
-        if ((conf->flags & flags) != flags)
-          continue;
-        if (EmptyString(conf->user) || EmptyString(conf->host))
-          return conf;
-        if (!match(conf->user, user) && !match(conf->host, host))
-          return conf;
-      }
-    }
-      break;
-
-  case CONF_SERVER:
-    DLINK_FOREACH(node, list->head)
-    {
-      conf = node->data;
-
-      if (name && !match(name, conf->name))
-        return conf;
-      if (host && !match(host, conf->host))
-        return conf;
-    }
-    break;
-
-  default:
-    break;
+    if (name && !compare(name, conf->name))
+      return conf;
+    if (host && !compare(host, conf->host))
+      return conf;
   }
+
   return NULL;
 }
 
@@ -640,106 +560,45 @@ find_matching_name_conf(enum maskitem_type type, const char *name, const char *u
  * side effects - looks for an exact match on name field
  */
 struct MaskItem *
-find_exact_name_conf(enum maskitem_type type, const struct Client *who, const char *name,
-                     const char *user, const char *host)
+operator_find(const struct Client *who, const char *name)
 {
   dlink_node *node = NULL;
-  dlink_list *list = map_to_list(type);
-  struct MaskItem *conf = NULL;
 
-  switch(type)
+  DLINK_FOREACH(node, operator_items.head)
   {
-  case CONF_XLINE:
-  case CONF_SHARED:
-  case CONF_NRESV:
-  case CONF_CRESV:
+    struct MaskItem *conf = node->data;
 
-    DLINK_FOREACH(node, list->head)
+    if (!irccmp(conf->name, name))
     {
-      conf = node->data;
+      if (!who)
+        return conf;
 
-      if (EmptyString(conf->name))
-        continue;
-
-      if (irccmp(conf->name, name) == 0)
+      if (!match(conf->user, who->username))
       {
-        if ((user == NULL && (host == NULL)))
-          return conf;
-        if (EmptyString(conf->user) || EmptyString(conf->host))
-          return conf;
-        if (!match(conf->user, user) && !match(conf->host, host))
-          return conf;
-      }
-    }
-    break;
-
-  case CONF_OPER:
-    DLINK_FOREACH(node, list->head)
-    {
-      conf = node->data;
-
-      if (EmptyString(conf->name))
-        continue;
-
-      if (!irccmp(conf->name, name))
-      {
-        if (!who)
-          return conf;
-        if (EmptyString(conf->user) || EmptyString(conf->host))
-          return NULL;
-        if (!match(conf->user, who->username))
+        switch (conf->htype)
         {
-          switch (conf->htype)
-          {
-            case HM_HOST:
-              if (!match(conf->host, who->host) || !match(conf->host, who->sockhost))
+          case HM_HOST:
+            if (!match(conf->host, who->host) || !match(conf->host, who->sockhost))
+              if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
+                return conf;
+            break;
+          case HM_IPV4:
+            if (who->connection->aftype == AF_INET)
+              if (match_ipv4(&who->connection->ip, &conf->addr, conf->bits))
                 if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
                   return conf;
-              break;
-            case HM_IPV4:
-              if (who->connection->aftype == AF_INET)
-                if (match_ipv4(&who->connection->ip, &conf->addr, conf->bits))
-                  if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
-                    return conf;
-              break;
-            case HM_IPV6:
-              if (who->connection->aftype == AF_INET6)
-                if (match_ipv6(&who->connection->ip, &conf->addr, conf->bits))
-                  if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
-                    return conf;
-              break;
-            default:
-              assert(0);
-          }
+            break;
+          case HM_IPV6:
+            if (who->connection->aftype == AF_INET6)
+              if (match_ipv6(&who->connection->ip, &conf->addr, conf->bits))
+                if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
+                  return conf;
+            break;
+          default:
+            assert(0);
         }
       }
     }
-
-    break;
-
-  case CONF_SERVER:
-    DLINK_FOREACH(node, list->head)
-    {
-      conf = node->data;
-
-      if (EmptyString(conf->name))
-        continue;
-
-      if (name == NULL)
-      {
-        if (EmptyString(conf->host))
-          continue;
-        if (irccmp(conf->host, host) == 0)
-          return conf;
-      }
-      else if (irccmp(conf->name, name) == 0)
-        return conf;
-    }
-
-    break;
-
-  default:
-    break;
   }
 
   return NULL;
@@ -762,25 +621,6 @@ set_default_conf(void)
    */
   assert(class_default == class_get_list()->tail->data);
 
-#ifdef HAVE_LIBCRYPTO
-#if OPENSSL_VERSION_NUMBER >= 0x009080FFL && !defined(OPENSSL_NO_ECDH)
-  {
-    EC_KEY *key = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
-
-    if (key)
-    {
-      SSL_CTX_set_tmp_ecdh(ConfigServerInfo.server_ctx, key);
-      EC_KEY_free(key);
-    }
-  }
-
-  SSL_CTX_set_options(ConfigServerInfo.server_ctx, SSL_OP_SINGLE_ECDH_USE);
-#endif
-
-  SSL_CTX_set_cipher_list(ConfigServerInfo.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
-  ConfigServerInfo.message_digest_algorithm = EVP_sha256();
-#endif
-
   ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
   ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
 
@@ -793,6 +633,7 @@ set_default_conf(void)
   ConfigServerInfo.max_nick_length = 9;
   ConfigServerInfo.max_topic_length = 80;
   ConfigServerInfo.hub = 0;
+  ConfigServerInfo.libgeoip_database_options = 0;
 
   log_del_all();
 
@@ -822,6 +663,7 @@ set_default_conf(void)
   ConfigGeneral.away_count = 2;
   ConfigGeneral.away_time = 10;
   ConfigGeneral.max_watch = 50;
+  ConfigGeneral.whowas_history_length = 15000;
   ConfigGeneral.cycle_on_host_change = 1;
   ConfigGeneral.dline_min_cidr = 16;
   ConfigGeneral.dline_min_cidr6 = 48;
@@ -899,6 +741,7 @@ read_conf(FILE *file)
   yyparse();  /* Load the values from the conf */
   validate_conf();  /* Check to make sure some values are still okay. */
                     /* Some global values are also loaded here. */
+  whowas_trim();  /* Attempt to trim whowas list if necessary */
   class_delete_marked();  /* Delete unused classes that are marked for deletion */
 }
 
@@ -999,31 +842,6 @@ conf_connect_allowed(struct irc_ssaddr *addr, int aftype)
   return 0;
 }
 
-/* expire_tklines()
- *
- * inputs       - tkline list pointer
- * output       - NONE
- * side effects - expire tklines
- */
-static void
-expire_tklines(dlink_list *list)
-{
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, list->head)
-  {
-    struct MaskItem *conf = node->data;
-
-    if (!conf->until || conf->until > CurrentTime)
-      continue;
-
-    if (ConfigGeneral.tkline_expire_notices)
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Temporary %s for [%s] expired",
-                           (conf->type == CONF_XLINE) ? "X-line" : "RESV", conf->name);
-    conf_free(conf);
-  }
-}
-
 /* cleanup_tklines()
  *
  * inputs       - NONE
@@ -1035,9 +853,8 @@ void
 cleanup_tklines(void *unused)
 {
   hostmask_expire_temporary();
-  expire_tklines(&gecos_items);
-  expire_tklines(&nresv_items);
-  expire_tklines(&cresv_items);
+  gecos_expire();
+  resv_expire();
 }
 
 /* oper_privs_as_string()
@@ -1046,11 +863,11 @@ cleanup_tklines(void *unused)
  * output        - pointer to static string showing oper privs
  * side effects  - return as string, the oper privs as derived from port
  */
-static const struct oper_privs
+static const struct oper_flags
 {
   const unsigned int flag;
   const unsigned char c;
-} flag_list[] = {
+} flag_table[] = {
   { OPER_FLAG_ADMIN,          'A' },
   { OPER_FLAG_CLOSE,          'B' },
   { OPER_FLAG_CONNECT,        'C' },
@@ -1083,21 +900,21 @@ static const struct oper_privs
 };
 
 const char *
-oper_privs_as_string(const unsigned int port)
+oper_privs_as_string(const unsigned int flags)
 {
-  static char privs_out[IRCD_BUFSIZE];
-  char *privs_ptr = privs_out;
+  static char buf[sizeof(flag_table) / sizeof(struct oper_flags)];
+  char *p = buf;
 
-  for (const struct oper_privs *opriv = flag_list; opriv->flag; ++opriv)
-    if (port & opriv->flag)
-      *privs_ptr++ = opriv->c;
+  for (const struct oper_flags *tab = flag_table; tab->flag; ++tab)
+    if (flags & tab->flag)
+      *p++ = tab->c;
 
-  if (privs_ptr == privs_out)
-    *privs_ptr++ = '0';
+  if (p == buf)
+    *p++ = '0';
 
-  *privs_ptr = '\0';
+  *p = '\0';
 
-  return privs_out;
+  return buf;
 }
 
 /*
@@ -1153,9 +970,7 @@ clear_out_old_conf(void)
 {
   dlink_node *node = NULL, *node_next = NULL;
   dlink_list *free_items [] = {
-    &server_items,   &operator_items,
-     &shared_items,   &gecos_items,
-     &nresv_items, &cluster_items,  &service_items, &cresv_items, NULL
+    &connect_items, &operator_items, NULL
   };
 
   dlink_list ** iterator = free_items; /* C is dumb */
@@ -1171,19 +986,13 @@ clear_out_old_conf(void)
       struct MaskItem *conf = node->data;
 
       conf->active = 0;
+      dlinkDelete(&conf->node, *iterator);
 
-      if (!IsConfDatabase(conf))
-      {
-        dlinkDelete(&conf->node, *iterator);
-
-        if (!conf->ref_count)
-          conf_free(conf);
-      }
+      if (!conf->ref_count)
+        conf_free(conf);
     }
   }
 
-  motd_clear();
-
   /*
    * Don't delete the class table, rather mark all entries for deletion.
    * The table is cleaned up by class_delete_marked. - avalon
@@ -1192,10 +1001,28 @@ clear_out_old_conf(void)
 
   clear_out_address_conf();
 
-  /* Clean out module paths */
-  mod_clear_paths();
+  modules_conf_clear();  /* Clear modules {} items */
 
-  pseudo_clear();
+  motd_clear();  /* Clear motd {} items and re-cache default motd */
+
+  cluster_clear();  /* Clear cluster {} items */
+
+  gecos_clear();  /* Clear gecos {} items */
+
+  resv_clear();  /* Clear resv {} items */
+
+  service_clear();  /* Clear service {} items */
+
+  shared_clear();  /* Clear shared {} items */
+
+  pseudo_clear();  /* Clear pseudo {} items */
+
+#ifdef HAVE_LIBGEOIP
+  GeoIP_delete(GeoIPv4_ctx);
+  GeoIPv4_ctx = NULL;
+  GeoIP_delete(GeoIPv6_ctx);
+  GeoIPv6_ctx = NULL;
+#endif
 
   /* Clean out ConfigServerInfo */
   xfree(ConfigServerInfo.description);
@@ -1204,16 +1031,22 @@ clear_out_old_conf(void)
   ConfigServerInfo.network_name = NULL;
   xfree(ConfigServerInfo.network_desc);
   ConfigServerInfo.network_desc = NULL;
-#ifdef HAVE_LIBCRYPTO
-  if (ConfigServerInfo.rsa_private_key)
-  {
-    RSA_free(ConfigServerInfo.rsa_private_key);
-    ConfigServerInfo.rsa_private_key = NULL;
-  }
-
+  xfree(ConfigServerInfo.libgeoip_ipv6_database_file);
+  ConfigServerInfo.libgeoip_ipv6_database_file = NULL;
+  xfree(ConfigServerInfo.libgeoip_ipv4_database_file);
+  ConfigServerInfo.libgeoip_ipv4_database_file = NULL;
   xfree(ConfigServerInfo.rsa_private_key_file);
   ConfigServerInfo.rsa_private_key_file = NULL;
-#endif
+  xfree(ConfigServerInfo.ssl_certificate_file);
+  ConfigServerInfo.ssl_certificate_file = NULL;
+  xfree(ConfigServerInfo.ssl_dh_param_file);
+  ConfigServerInfo.ssl_dh_param_file = NULL;
+  xfree(ConfigServerInfo.ssl_dh_elliptic_curve);
+  ConfigServerInfo.ssl_dh_elliptic_curve = NULL;
+  xfree(ConfigServerInfo.ssl_cipher_list);
+  ConfigServerInfo.ssl_cipher_list = NULL;
+  xfree(ConfigServerInfo.ssl_message_digest_algorithm);
+  ConfigServerInfo.ssl_message_digest_algorithm = NULL;
 
   /* Clean out ConfigAdminInfo */
   xfree(ConfigAdminInfo.name);
@@ -1230,6 +1063,25 @@ clear_out_old_conf(void)
   listener_close_marked();
 }
 
+static void
+conf_handle_tls(int cold)
+{
+  if (!tls_new_cred())
+  {
+    if (cold)
+    {
+      ilog(LOG_TYPE_IRCD, "Error while initializing TLS");
+      exit(EXIT_FAILURE);
+    }
+    else
+    {
+      /* Failed to load new settings/certs, old ones remain active */
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                           "Error reloading TLS settings, check the ircd log"); // report_crypto_errors logs this
+    }
+  }
+}
+
 /* read_conf_files()
  *
  * inputs       - cold start YES or NO
@@ -1278,6 +1130,7 @@ read_conf_files(int cold)
   fclose(conf_parser_ctx.conf_file);
 
   log_reopen_all();
+  conf_handle_tls(cold);
 
   isupport_add("NICKLEN", NULL, ConfigServerInfo.max_nick_length);
   isupport_add("NETWORK", ConfigServerInfo.network_name, -1);
@@ -1294,12 +1147,6 @@ read_conf_files(int cold)
   isupport_add("CHANNELLEN", NULL, CHANNELLEN);
   isupport_add("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
   isupport_add("CHANMODES", chanmodes, -1);
-
-  /*
-   * message_locale may have changed.  rebuild isupport since it relies
-   * on strlen(form_str(RPL_ISUPPORT))
-   */
-  isupport_rebuild();
 }
 
 /* conf_add_class_to_conf()
@@ -1371,12 +1218,12 @@ conf_error_report(const char *msg)
  * side effects - none
  * Originally written by Dianora (Diane, db@db.net)
  */
-time_t
+uintmax_t
 valid_tkline(const char *data, const int minutes)
 {
   const unsigned char *p = (const unsigned char *)data;
   unsigned char tmpch = '\0';
-  time_t result = 0;
+  uintmax_t result = 0;
 
   while ((tmpch = *p++))
   {
@@ -1452,7 +1299,7 @@ valid_wild_card_simple(const char *data)
  * side effects - NOTICE is given to source_p if warn is 1
  */
 int
-valid_wild_card(struct Client *source_p, int count, ...)
+valid_wild_card(int count, ...)
 {
   unsigned char tmpch = '\0';
   unsigned int nonwild = 0;
@@ -1495,10 +1342,6 @@ valid_wild_card(struct Client *source_p, int count, ...)
     }
   }
 
-  if (IsClient(source_p))
-    sendto_one_notice(source_p, &me,
-                      ":Please include at least %u non-wildcard characters with the mask",
-                      ConfigGeneral.min_nonwildcard);
   va_end(args);
   return 0;
 }
@@ -1615,10 +1458,10 @@ find_user_host(struct Client *source_p, char *user_host_or_nick,
 int
 parse_aline(const char *cmd, struct Client *source_p,
             int parc, char **parv,
-            int parse_flags, char **up_p, char **h_p, time_t *tkline_time,
+            char **up_p, char **h_p, uintmax_t *tkline_time,
             char **target_server, char **reason)
 {
-  int found_tkline_time=0;
+  uintmax_t found_tkline_time=0;
   static char default_reason[] = CONF_NOREASON;
   static char user[USERLEN*4+1];
   static char host[HOSTLEN*4+1];
@@ -1695,21 +1538,6 @@ parse_aline(const char *cmd, struct Client *source_p,
     }
   }
 
-  if (h_p)
-  {
-    if (strchr(user, '!'))
-    {
-      sendto_one_notice(source_p, &me, ":Invalid character '!' in kline");
-      return 0;
-    }
-
-    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 2, *up_p, *h_p))
-      return 0;
-  }
-  else
-    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 1, *up_p))
-      return 0;
-
   if (reason)
   {
     if (parc && !EmptyString(*parv))
@@ -1744,40 +1572,6 @@ match_conf_password(const char *password, const struct MaskItem *conf)
   return encr && !strcmp(encr, conf->passwd);
 }
 
-/*
- * cluster_a_line
- *
- * inputs	- client sending the cluster
- *		- command name "KLINE" "XLINE" etc.
- *		- capab -- CAPAB_KLN etc. from server.h
- *		- cluster type -- CLUSTER_KLINE etc. from conf.h
- *		- pattern and args to send along
- * output	- none
- * side effects	- Take source_p send the pattern with args given
- *		  along to all servers that match capab and cluster type
-*/
-void
-cluster_a_line(struct Client *source_p, const char *command, unsigned int capab,
-               unsigned int cluster_type, const char *pattern, ...)
-{
-  va_list args;
-  char buffer[IRCD_BUFSIZE] = "";
-  const dlink_node *node = NULL;
-
-  va_start(args, pattern);
-  vsnprintf(buffer, sizeof(buffer), pattern, args);
-  va_end(args);
-
-  DLINK_FOREACH(node, cluster_items.head)
-  {
-    const struct MaskItem *conf = node->data;
-
-    if (conf->flags & cluster_type)
-      sendto_match_servs(source_p, conf->name, CAPAB_CLUSTER | capab,
-                         "%s %s %s", command, conf->name, buffer);
-  }
-}
-
 /*
  * split_nuh
  *
