@@ -22,19 +22,20 @@
 
 /*! \file conf_db.c
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: conf_db.c 7303 2016-02-10 10:34:25Z michael $
  */
 
 
 #include "stdinc.h"
+#include "conf.h"
 #include "conf_db.h"
+#include "conf_gecos.h"
+#include "conf_resv.h"
 #include "memory.h"
 #include "log.h"
 #include "send.h"
 #include "irc_string.h"
-#include "conf.h"
 #include "hostmask.h"
-#include "resv.h"
 
 
 /*! \brief Return the version number on the file.  Return 0 if there is no version
@@ -669,54 +670,54 @@ save_resv_database(const char *filename)
 {
   uint32_t records = 0;
   struct dbFILE *f = NULL;
-  dlink_node *ptr = NULL;
-  struct MaskItem *conf = NULL;
+  dlink_node *node = NULL;
+  const struct ResvItem *resv = NULL;
 
   if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
-  DLINK_FOREACH(ptr, cresv_items.head)
+  DLINK_FOREACH(node, resv_chan_get_list()->head)
   {
-    conf = ptr->data;
+    resv = node->data;
 
-    if (IsConfDatabase(conf))
+    if (resv->in_database)
       ++records;
   }
 
-  DLINK_FOREACH(ptr, nresv_items.head)
+  DLINK_FOREACH(node, resv_nick_get_list()->head)
   {
-    conf = ptr->data;
+    resv = node->data;
 
-    if (IsConfDatabase(conf))
+    if (resv->in_database)
       ++records;
   }
 
   SAFE_WRITE(write_uint32(records, f), filename);
 
-  DLINK_FOREACH(ptr, cresv_items.head)
+  DLINK_FOREACH(node, resv_chan_get_list()->head)
   {
-    conf = ptr->data;
+    resv = node->data;
 
-    if (!IsConfDatabase(conf))
+    if (!resv->in_database)
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), filename);
-    SAFE_WRITE(write_string(conf->reason, f), filename);
-    SAFE_WRITE(write_uint64(conf->setat, f), filename);
-    SAFE_WRITE(write_uint64(conf->until, f), filename);
+    SAFE_WRITE(write_string(resv->mask, f), filename);
+    SAFE_WRITE(write_string(resv->reason, f), filename);
+    SAFE_WRITE(write_uint64(resv->setat, f), filename);
+    SAFE_WRITE(write_uint64(resv->expire, f), filename);
   }
 
-  DLINK_FOREACH(ptr, nresv_items.head)
+  DLINK_FOREACH(node, resv_nick_get_list()->head)
   {
-    conf = ptr->data;
+    resv = node->data;
 
-    if (!IsConfDatabase(conf))
+    if (!resv->in_database)
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), filename);
-    SAFE_WRITE(write_string(conf->reason, f), filename);
-    SAFE_WRITE(write_uint64(conf->setat, f), filename);
-    SAFE_WRITE(write_uint64(conf->until, f), filename);
+    SAFE_WRITE(write_string(resv->mask, f), filename);
+    SAFE_WRITE(write_string(resv->reason, f), filename);
+    SAFE_WRITE(write_uint64(resv->setat, f), filename);
+    SAFE_WRITE(write_uint64(resv->expire, f), filename);
   }
 
   close_db(f);
@@ -731,7 +732,7 @@ load_resv_database(const char *filename)
   struct dbFILE *f = NULL;
   char *name = NULL;
   char *reason = NULL;
-  struct MaskItem *conf = NULL;
+  struct ResvItem *resv = NULL;
 
   if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
@@ -751,12 +752,12 @@ load_resv_database(const char *filename)
     SAFE_READ(read_uint64(&tmp64_setat, f));
     SAFE_READ(read_uint64(&tmp64_hold, f));
 
-    if ((conf = create_resv(name, reason, NULL)) == NULL)
+    if ((resv = resv_make(name, reason, NULL)) == NULL)
       continue;
 
-    conf->setat = tmp64_setat;
-    conf->until = tmp64_hold;
-    SetConfDatabase(conf);
+    resv->setat = tmp64_setat;
+    resv->expire = tmp64_hold;
+    resv->in_database = 1;
 
     xfree(name);
     xfree(reason);
@@ -771,32 +772,32 @@ save_xline_database(const char *filename)
   uint32_t records = 0;
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
-  struct MaskItem *conf = NULL;
+  struct GecosItem *gecos = NULL;
 
   if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
-  DLINK_FOREACH(ptr, gecos_items.head)
+  DLINK_FOREACH(ptr, gecos_get_list()->head)
   {
-    conf = ptr->data;
+    gecos = ptr->data;
 
-    if (IsConfDatabase(conf))
+    if (gecos->in_database)
       ++records;
   }
 
   SAFE_WRITE(write_uint32(records, f), filename);
 
-  DLINK_FOREACH(ptr, gecos_items.head)
+  DLINK_FOREACH(ptr, gecos_get_list()->head)
   {
-    conf = ptr->data;
+    gecos = ptr->data;
 
-    if (!IsConfDatabase(conf))
+    if (!gecos->in_database)
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), filename);
-    SAFE_WRITE(write_string(conf->reason, f), filename);
-    SAFE_WRITE(write_uint64(conf->setat, f), filename);
-    SAFE_WRITE(write_uint64(conf->until, f), filename);
+    SAFE_WRITE(write_string(gecos->mask, f), filename);
+    SAFE_WRITE(write_string(gecos->reason, f), filename);
+    SAFE_WRITE(write_uint64(gecos->setat, f), filename);
+    SAFE_WRITE(write_uint64(gecos->expire, f), filename);
   }
 
   close_db(f);
@@ -811,7 +812,7 @@ load_xline_database(const char *filename)
   struct dbFILE *f = NULL;
   char *name = NULL;
   char *reason = NULL;
-  struct MaskItem *conf = NULL;
+  struct GecosItem *gecos = NULL;
 
   if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
@@ -831,14 +832,12 @@ load_xline_database(const char *filename)
     SAFE_READ(read_uint64(&tmp64_setat, f));
     SAFE_READ(read_uint64(&tmp64_hold, f));
 
-    conf = conf_make(CONF_XLINE);
-
-    SetConfDatabase(conf);
-
-    conf->name = name;
-    conf->reason = reason;
-    conf->setat = tmp64_setat;
-    conf->until = tmp64_hold;
+    gecos = gecos_make();
+    gecos->in_database = 1;
+    gecos->mask = name;
+    gecos->reason = reason;
+    gecos->setat = tmp64_setat;
+    gecos->expire = tmp64_hold;
   }
 
   close_db(f);
