@@ -21,16 +21,13 @@
 
 /*! \file event.c
  * \brief Timer based event execution
- * \version $Id: event.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: event.c 7481 2016-03-16 09:18:07Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
 #include "ircd.h"
 #include "event.h"
-#include "client.h"
-#include "send.h"
-#include "numeric.h"
 #include "rng_mt.h"
 
 
@@ -72,7 +69,7 @@ event_addish(struct event *ev, void *data)
 {
   if (ev->when >= 3)
   {
-    const time_t two_third = (2 * ev->when) / 3;
+    const uintmax_t two_third = (2 * ev->when) / 3;
 
     ev->when = two_third + ((genrand_int32() % 1000) * two_third) / 1000;
   }
@@ -93,38 +90,37 @@ event_delete(struct event *ev)
 void
 event_run(void)
 {
-  static time_t last = 0;
-  unsigned int len = 0;
+  static uintmax_t last = 0;
 
   if (last == CurrentTime)
     return;
   last = CurrentTime;
 
-  len = dlink_list_length(&event_list);
+  unsigned int len = dlink_list_length(&event_list);
   while (len-- && dlink_list_length(&event_list))
   {
-    struct event *e = event_list.head->data;
+    struct event *ev = event_list.head->data;
 
-    if (e->next > CurrentTime)
+    if (ev->next > CurrentTime)
       break;
 
-    event_delete(e);
+    event_delete(ev);
 
-    e->handler(e->data);
+    ev->handler(ev->data);
 
-    if (!e->oneshot)
-      event_add(e, e->data);
+    if (!ev->oneshot)
+      event_add(ev, ev->data);
   }
 }
 
 /*
- * void event_set_back_events(time_t by)
+ * void event_set_back_events(uintmax_t by)
  * Input: Time to set back events by.
  * Output: None.
  * Side-effects: Sets back all events by "by" seconds.
  */
 void
-event_set_back_events(time_t by)
+event_set_back_events(uintmax_t by)
 {
   dlink_node *node;
 
