@@ -21,7 +21,7 @@
 
 /*! \file fdlist.c
  * \brief Maintains a list of file descriptors.
- * \version $Id: fdlist.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: fdlist.c 7106 2016-01-23 20:17:08Z michael $
  */
 
 #include "stdinc.h"
@@ -129,10 +129,8 @@ fd_close(fde_t *F)
 
   delete_resolver_queries(F);
 
-#ifdef HAVE_LIBCRYPTO
-  if (F->ssl)
-    SSL_free(F->ssl);
-#endif
+  if (tls_isusing(&F->ssl))
+    tls_free(&F->ssl);
 
   if (fd_hash[hashv] == F)
     fd_hash[hashv] = F->hnext;
