@@ -21,7 +21,7 @@
 
 /*! \file hash.c
  * \brief Hash table management.
- * \version $Id: hash.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: hash.c 7483 2016-03-16 09:28:00Z michael $
  */
 
 #include "stdinc.h"
@@ -30,10 +30,8 @@
 #include "channel.h"
 #include "channel_mode.h"
 #include "client.h"
-#include "modules.h"
 #include "hash.h"
 #include "id.h"
-#include "resv.h"
 #include "rng_mt.h"
 #include "userhost.h"
 #include "irc_string.h"
@@ -41,9 +39,7 @@
 #include "numeric.h"
 #include "send.h"
 #include "memory.h"
-#include "mempool.h"
 #include "dbuf.h"
-#include "user.h"
 
 
 static unsigned int hashf_xor_key;
