@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: ircd.c 7439 2016-03-10 20:03:41Z michael $
  */
 
 #include "stdinc.h"
@@ -62,14 +62,15 @@
 
 
 #ifdef HAVE_LIBGEOIP
-GeoIP *geoip_ctx;
+GeoIP *GeoIPv4_ctx;
+GeoIP *GeoIPv6_ctx;
 #endif
 
 struct SetOptions GlobalSetOptions;  /* /quote set variables */
 struct Counter Count;
 struct ServerState_t server_state;
 struct ServerStatistics ServerStats;
-struct timeval SystemTime;
+struct ServerTime SystemTime;
 struct Connection meConnection;  /* That's also part of me */
 struct Client me = { .connection = &meConnection };  /* That's me */
 
@@ -155,14 +156,14 @@ set_time(void)
     server_die(buf, SERVER_SHUTDOWN);
   }
 
-  if (newtime.tv_sec < CurrentTime)
+  if ((uintmax_t)newtime.tv_sec < CurrentTime)
   {
     ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%ju < %ju)",
-         newtime.tv_sec, CurrentTime);
+         (uintmax_t)newtime.tv_sec, CurrentTime);
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
                          "System clock is running backwards - (%ju < %ju)",
-                         newtime.tv_sec, CurrentTime);
-    event_set_back_events(CurrentTime - newtime.tv_sec);
+                         (uintmax_t)newtime.tv_sec, CurrentTime);
+    event_set_back_events(CurrentTime - (uintmax_t)newtime.tv_sec);
   }
 
   SystemTime.tv_sec = newtime.tv_sec;
@@ -329,76 +330,6 @@ setup_corefile(void)
 #endif
 }
 
-#ifdef HAVE_LIBCRYPTO
-static int
-always_accept_verify_cb(int preverify_ok, X509_STORE_CTX *x509_ctx)
-{
-  return 1;
-}
-#endif
-
-/* ssl_init()
- *
- * inputs       - nothing
- * output       - nothing
- * side effects - setups SSL context.
- */
-static void
-ssl_init(void)
-{
-#ifdef HAVE_LIBCRYPTO
-  SSL_load_error_strings();
-  SSLeay_add_ssl_algorithms();
-
-  if (!(ConfigServerInfo.server_ctx = SSL_CTX_new(SSLv23_server_method())))
-  {
-    const char *s = ERR_lib_error_string(ERR_get_error());
-
-    fprintf(stderr, "ERROR: Could not initialize the SSL Server context -- %s\n", s);
-    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the SSL Server context -- %s", s);
-    exit(EXIT_FAILURE);
-    return;  /* Not reached */
-  }
-
-  SSL_CTX_set_options(ConfigServerInfo.server_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TICKET);
-  SSL_CTX_set_options(ConfigServerInfo.server_ctx, SSL_OP_SINGLE_DH_USE|SSL_OP_CIPHER_SERVER_PREFERENCE);
-  SSL_CTX_set_verify(ConfigServerInfo.server_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
-                     always_accept_verify_cb);
-  SSL_CTX_set_session_cache_mode(ConfigServerInfo.server_ctx, SSL_SESS_CACHE_OFF);
-  SSL_CTX_set_cipher_list(ConfigServerInfo.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
-
-#if OPENSSL_VERSION_NUMBER >= 0x009080FFL && !defined(OPENSSL_NO_ECDH)
-  {
-    EC_KEY *key = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
-
-    if (key)
-    {
-      SSL_CTX_set_tmp_ecdh(ConfigServerInfo.server_ctx, key);
-      EC_KEY_free(key);
-    }
-  }
-
-  SSL_CTX_set_options(ConfigServerInfo.server_ctx, SSL_OP_SINGLE_ECDH_USE);
-#endif
-
-  if (!(ConfigServerInfo.client_ctx = SSL_CTX_new(SSLv23_client_method())))
-  {
-    const char *s = ERR_lib_error_string(ERR_get_error());
-
-    fprintf(stderr, "ERROR: Could not initialize the SSL Client context -- %s\n", s);
-    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the SSL Client context -- %s", s);
-    exit(EXIT_FAILURE);
-    return;  /* Not reached */
-  }
-
-  SSL_CTX_set_options(ConfigServerInfo.client_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TICKET);
-  SSL_CTX_set_options(ConfigServerInfo.client_ctx, SSL_OP_SINGLE_DH_USE);
-  SSL_CTX_set_verify(ConfigServerInfo.client_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
-                     always_accept_verify_cb);
-  SSL_CTX_set_session_cache_mode(ConfigServerInfo.client_ctx, SSL_SESS_CACHE_OFF);
-#endif /* HAVE_LIBCRYPTO */
-}
-
 /*
  * print_startup - print startup information
  */
@@ -475,8 +406,6 @@ main(int argc, char *argv[])
     exit(EXIT_FAILURE);
   }
 
-  ssl_init();
-
   if (!server_state.foreground)
   {
     make_daemon();
@@ -492,6 +421,7 @@ main(int argc, char *argv[])
   log_set_file(LOG_TYPE_IRCD, 0, logFileName);
 
   init_netio();         /* This needs to be setup early ! -- adrian */
+  tls_init();
 
   /* Check if there is pidfile and daemon already running */
   check_pidfile(pidFileName);
@@ -517,9 +447,6 @@ main(int argc, char *argv[])
   read_links_file();
   motd_init();
   user_modes_init();
-#ifdef HAVE_LIBGEOIP
-  geoip_ctx = GeoIP_new(GEOIP_MEMORY_CACHE);
-#endif
 
   if (EmptyString(ConfigServerInfo.name))
   {
