@@ -21,7 +21,7 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: listener.c 7350 2016-02-21 11:56:06Z michael $
  */
 
 #include "stdinc.h"
@@ -72,7 +72,7 @@ listener_free(struct Listener *listener)
  * returns "host.foo.org/6667" for a given listener
  */
 const char *
-listener_get_name(const struct Listener *const listener)
+listener_get_name(const struct Listener *listener)
 {
   static char buf[HOSTLEN + HOSTIPLEN + PORTNAMELEN + 4];  /* +4 for [,/,],\0 */
 
@@ -81,10 +81,17 @@ listener_get_name(const struct Listener *const listener)
   return buf;
 }
 
+void
+listener_count_memory(unsigned int *count, size_t *bytes)
+{
+  (*count) = dlink_list_length(&listener_list);
+  (*bytes) = *count * sizeof(struct Listener);
+}
+
 static void
 listener_accept_connection(fde_t *pfd, void *data)
 {
-  static time_t rate = 0;
+  static uintmax_t rate = 0;
   struct irc_ssaddr addr;
   int fd;
   int pe;
