@@ -33,7 +33,7 @@
 
 /*! \file mempool.c
  * \brief A pooling allocator
- * \version $Id: mempool.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: mempool.c 7500 2016-03-22 19:48:49Z michael $
  */
 
 #include "stdinc.h"
@@ -284,7 +284,6 @@ mp_pool_get(mp_pool_t *pool)
 {
   mp_chunk_t *chunk;
   mp_allocated_t *allocated;
-  void *ptr = NULL;
 
   if (pool->used_chunks)
   {
@@ -375,7 +374,7 @@ mp_pool_get(mp_pool_t *pool)
   }
 
   /* And return the memory portion of the mp_allocated_t. */
-  ptr = A2M(allocated);
+  void *ptr = A2M(allocated);
   memset(ptr, 0, pool->item_size);
 
   return ptr;
