@@ -21,7 +21,7 @@
 
 /*! \file modules.c
  * \brief A module loader.
- * \version $Id: modules.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: modules.c 7498 2016-03-22 19:46:44Z michael $
  */
 
 #include "ltdl.h"
@@ -230,8 +230,7 @@ mod_add_path(const char *path)
     return;
 
   pathst = xcalloc(sizeof(struct module_path));
-
-  strlcpy(pathst->path, path, sizeof(pathst->path));
+  pathst->path = xstrdup(path);
   dlinkAdd(pathst, &pathst->node, &modules_path);
 }
 
@@ -247,8 +246,7 @@ add_conf_module(const char *name)
   struct module_path *pathst;
 
   pathst = xcalloc(sizeof(struct module_path));
-
-  strlcpy(pathst->path, name, sizeof(pathst->path));
+  pathst->path = xstrdup(name);
   dlinkAdd(pathst, &pathst->node, &modules_conf);
 }
 
@@ -259,20 +257,24 @@ add_conf_module(const char *name)
  * side effects - clear the lists of paths and conf modules
  */
 void
-mod_clear_paths(void)
+modules_conf_clear(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, modules_path.head)
+  while (modules_path.head)
   {
-    dlinkDelete(node, &modules_path);
-    xfree(node->data);
+    struct module_path *path = modules_path.head->data;
+
+    dlinkDelete(&path->node, &modules_path);
+    xfree(path->path);
+    xfree(path);
   }
 
-  DLINK_FOREACH_SAFE(node, node_next, modules_conf.head)
+  while (modules_conf.head)
   {
-    dlinkDelete(node, &modules_conf);
-    xfree(node->data);
+    struct module_path *path = modules_conf.head->data;
+
+    dlinkDelete(&path->node, &modules_conf);
+    xfree(path->path);
+    xfree(path);
   }
 }
 
