@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: motd.c 7265 2016-02-06 19:01:29Z michael $
  */
 
 #include "stdinc.h"
@@ -383,15 +383,14 @@ motd_add(const char *mask, const char *path)
 void
 motd_clear(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
   motd_decache(MotdList.local);  /* Decache local and remote MOTDs */
   motd_decache(MotdList.remote);
 
-  DLINK_FOREACH_SAFE(node, node_next, MotdList.other.head)  /* Destroy other MOTDs */
+  while (MotdList.other.head)  /* Destroy other MOTDs */
   {
-    dlinkDelete(node, &MotdList.other);
-    motd_destroy(node->data);
+    struct Motd *motd = MotdList.other.head->data;
+    dlinkDelete(&motd->node, &MotdList.other);
+    motd_destroy(motd);
   }
 
   /* Now recache local and remote MOTDs */
