@@ -21,7 +21,7 @@
 
 /*! \file packet.c
  * \brief Packet handlers.
- * \version $Id: packet.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: packet.c 7114 2016-01-23 20:31:37Z michael $
  */
 
 #include "stdinc.h"
@@ -289,6 +289,7 @@ read_packet(fde_t *fd, void *data)
 {
   struct Client *const client_p = data;
   int length = 0;
+  int want_write = 0;
 
   if (IsDefunct(client_p))
     return;
@@ -300,34 +301,15 @@ read_packet(fde_t *fd, void *data)
    */
   do
   {
-#ifdef HAVE_LIBCRYPTO
-    if (fd->ssl)
+    if (tls_isusing(&fd->ssl))
     {
-      length = SSL_read(fd->ssl, readBuf, sizeof(readBuf));
+      length = tls_read(&fd->ssl, readBuf, sizeof(readBuf), &want_write);
 
-      /* translate openssl error codes, sigh */
-      if (length < 0)
-        switch (SSL_get_error(fd->ssl, length))
-        {
-          case SSL_ERROR_WANT_WRITE:
-            comm_setselect(fd, COMM_SELECT_WRITE, sendq_unblocked, client_p, 0);
-            return;
-          case SSL_ERROR_WANT_READ:
-              errno = EWOULDBLOCK;
-          case SSL_ERROR_SYSCALL:
-              break;
-          case SSL_ERROR_SSL:
-            if (errno == EAGAIN)
-              break;
-          default:
-            length = errno = 0;
-        }
+      if (want_write)
+        comm_setselect(fd, COMM_SELECT_WRITE, sendq_unblocked, client_p, 0);
     }
     else
-#endif
-    {
       length = recv(fd->fd, readBuf, sizeof(readBuf), 0);
-    }
 
     if (length <= 0)
     {
@@ -366,12 +348,7 @@ read_packet(fde_t *fd, void *data)
       exit_client(client_p, "Excess Flood");
       return;
     }
-  }
-#ifdef HAVE_LIBCRYPTO
-  while (length == sizeof(readBuf) || fd->ssl);
-#else
-  while (length == sizeof(readBuf));
-#endif
+  } while (length == sizeof(readBuf) || tls_isusing(&fd->ssl));
 
   /* If we get here, we need to register for another COMM_SELECT_READ */
   comm_setselect(fd, COMM_SELECT_READ, read_packet, client_p, 0);
