@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_kqueue.c
  * \brief kqueue() compatible network routines.
- * \version $Id: s_bsd_kqueue.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: s_bsd_kqueue.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -88,7 +88,7 @@ kq_update_events(int fd, int filter, int what)
  */
 void
 comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
-               void *client_data, time_t timeout)
+               void *client_data, uintmax_t timeout)
 {
   int new_events, diff;
 
