@@ -21,7 +21,7 @@
 
 /*! \file send.c
  * \brief Functions for sending messages.
- * \version $Id: send.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: send.c 7380 2016-03-02 17:51:43Z michael $
  */
 
 #include "stdinc.h"
@@ -126,7 +126,7 @@ send_message(struct Client *to, struct dbuf_block *buf)
  *
  */
 static void
-send_message_remote(struct Client *to, struct Client *from, struct dbuf_block *buf)
+send_message_remote(struct Client *to, const struct Client *from, struct dbuf_block *buf)
 {
   assert(MyConnect(to));
   assert(IsServer(to));
@@ -168,6 +168,7 @@ void
 send_queued_write(struct Client *to)
 {
   int retlen = 0;
+  int want_read = 0;
 
   /*
    ** Once socket is marked dead, we cannot start writing to it,
@@ -183,33 +184,17 @@ send_queued_write(struct Client *to)
     {
       const struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
 
-#ifdef HAVE_LIBCRYPTO
-      if (to->connection->fd.ssl)
+      if (tls_isusing(&to->connection->fd.ssl))
       {
-        retlen = SSL_write(to->connection->fd.ssl, first->data + to->connection->buf_sendq.pos, first->size - to->connection->buf_sendq.pos);
+        retlen = tls_write(&to->connection->fd.ssl, first->data + to->connection->buf_sendq.pos,
+                                                    first->size - to->connection->buf_sendq.pos, &want_read);
 
-        /* translate openssl error codes, sigh */
-        if (retlen < 0)
-        {
-          switch (SSL_get_error(to->connection->fd.ssl, retlen))
-          {
-            case SSL_ERROR_WANT_READ:
-              return;  /* retry later, don't register for write events */
-            case SSL_ERROR_WANT_WRITE:
-              errno = EWOULDBLOCK;
-            case SSL_ERROR_SYSCALL:
-              break;
-            case SSL_ERROR_SSL:
-              if (errno == EAGAIN)
-                break;
-            default:
-              retlen = errno = 0;  /* either an SSL-specific error or EOF */
-          }
-        }
+        if (want_read)
+          return;  /* Retry later, don't register for write events */
       }
       else
-#endif
-        retlen = send(to->connection->fd.fd, first->data + to->connection->buf_sendq.pos, first->size - to->connection->buf_sendq.pos, 0);
+        retlen = send(to->connection->fd.fd, first->data + to->connection->buf_sendq.pos,
+                                             first->size - to->connection->buf_sendq.pos, 0);
 
       if (retlen <= 0)
         break;
@@ -226,8 +211,7 @@ send_queued_write(struct Client *to)
       AddFlag(to, FLAGS_BLOCKED);
 
       /* we have a non-fatal error, reschedule a write */
-      comm_setselect(&to->connection->fd, COMM_SELECT_WRITE,
-                     sendq_unblocked, to, 0);
+      comm_setselect(&to->connection->fd, COMM_SELECT_WRITE, sendq_unblocked, to, 0);
     }
     else if (retlen <= 0)
     {
@@ -296,7 +280,7 @@ sendto_one(struct Client *to, const char *pattern, ...)
 }
 
 void
-sendto_one_numeric(struct Client *to, struct Client *from, enum irc_numerics numeric, ...)
+sendto_one_numeric(struct Client *to, const struct Client *from, enum irc_numerics numeric, ...)
 {
   struct dbuf_block *buffer = NULL;
   const char *dest = NULL, *numstr = NULL;
@@ -330,7 +314,7 @@ sendto_one_numeric(struct Client *to, struct Client *from, enum irc_numerics num
 }
 
 void
-sendto_one_notice(struct Client *to, struct Client *from, const char *pattern, ...)
+sendto_one_notice(struct Client *to, const struct Client *from, const char *pattern, ...)
 {
   struct dbuf_block *buffer = NULL;
   const char *dest = NULL;
@@ -369,7 +353,7 @@ sendto_one_notice(struct Client *to, struct Client *from, const char *pattern, .
  * WARNING - +D clients are ignored
  */
 void
-sendto_channel_butone(struct Client *one, struct Client *from,
+sendto_channel_butone(struct Client *one, const struct Client *from,
                       struct Channel *chptr, unsigned int type,
                       const char *pattern, ...)
 {
@@ -441,7 +425,7 @@ sendto_channel_butone(struct Client *one, struct Client *from,
  * -davidt
  */
 void
-sendto_server(struct Client *one,
+sendto_server(const struct Client *one,
               const unsigned int caps,
               const unsigned int nocaps,
               const char *format, ...)
@@ -619,8 +603,8 @@ match_it(const struct Client *one, const char *mask, unsigned int what)
  * ugh. ONLY used by m_message.c to send an "oper magic" message. ugh.
  */
 void
-sendto_match_butone(struct Client *one, struct Client *from, const char *mask,
-                    int what, const char *pattern, ...)
+sendto_match_butone(const struct Client *one, const struct Client *from,
+                    const char *mask, int what, const char *pattern, ...)
 {
   va_list alocal, aremote;
   dlink_node *node = NULL;
@@ -695,7 +679,7 @@ sendto_match_butone(struct Client *one, struct Client *from, const char *mask,
  * side effects	- data sent to servers matching with capab
  */
 void
-sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
+sendto_match_servs(const struct Client *source_p, const char *mask, unsigned int cap,
                    const char *pattern, ...)
 {
   va_list args;
@@ -729,7 +713,7 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
      */
     target_p->from->connection->serial = current_serial;
 
-    if (!IsCapable(target_p->from, cap))
+    if (cap && IsCapable(target_p->from, cap) != cap)
       continue;
 
     send_message_remote(target_p->from, source_p, buffer);
@@ -748,7 +732,7 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
  * 		  but useful when one does not know where target "lives"
  */
 void
-sendto_anywhere(struct Client *to, struct Client *from,
+sendto_anywhere(struct Client *to, const struct Client *from,
                 const char *command,
                 const char *pattern, ...)
 {
@@ -828,8 +812,7 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
       continue;
 
     if (HasUMode(client_p, flags))
-      sendto_one(client_p, ":%s NOTICE %s :*** %s -- %s",
-                 me.name, client_p->name, ntype, nbuf);
+      sendto_one_notice(client_p, &me, ":*** %s -- %s", ntype, nbuf);
   }
 }
 
@@ -841,7 +824,7 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
  *                (at most 5 warnings every 5 seconds)
  */
 void
-sendto_realops_flags_ratelimited(time_t *rate, const char *pattern, ...)
+sendto_realops_flags_ratelimited(uintmax_t *rate, const char *pattern, ...)
 {
   va_list args;
   char buffer[IRCD_BUFSIZE] = "";
@@ -868,7 +851,7 @@ sendto_realops_flags_ratelimited(time_t *rate, const char *pattern, ...)
  * side effects - Send a wallops to local opers
  */
 void
-sendto_wallops_flags(unsigned int flags, struct Client *source_p,
+sendto_wallops_flags(unsigned int flags, const struct Client *source_p,
                      const char *pattern, ...)
 {
   dlink_node *node = NULL;
