@@ -21,7 +21,7 @@
 
 /*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: user.c 7303 2016-02-10 10:34:25Z michael $
  */
 
 #include "stdinc.h"
@@ -38,6 +38,7 @@
 #include "motd.h"
 #include "numeric.h"
 #include "conf.h"
+#include "conf_gecos.h"
 #include "log.h"
 #include "server.h"
 #include "send.h"
@@ -49,6 +50,7 @@
 #include "parse.h"
 #include "watch.h"
 #include "isupport.h"
+#include "tls.h"
 
 static char umode_buffer[IRCD_BUFSIZE];
 
@@ -211,7 +213,7 @@ introduce_client(struct Client *source_p)
   dlink_node *node = NULL;
   char ubuf[IRCD_BUFSIZE] = "";
 
-  if (MyClient(source_p))
+  if (MyConnect(source_p))
     send_umode(source_p, source_p, 0, ubuf);
   else
     send_umode(NULL, source_p, 0, ubuf);
@@ -256,14 +258,12 @@ user_welcome(struct Client *source_p)
 {
   static const char built_date[] = __DATE__ " at " __TIME__;
 
-#ifdef HAVE_LIBCRYPTO
   if (HasFlag(source_p, FLAGS_SSL))
   {
     AddUMode(source_p, UMODE_SSL);
     sendto_one_notice(source_p, &me, ":*** Connected securely via %s",
-                      ssl_get_cipher(source_p->connection->fd.ssl));
+                      tls_get_cipher(&source_p->connection->fd.ssl));
   }
-#endif
 
   sendto_one_numeric(source_p, &me, RPL_WELCOME, ConfigServerInfo.network_name,
                      source_p->name);
@@ -286,17 +286,16 @@ user_welcome(struct Client *source_p)
 static int
 check_xline(struct Client *source_p)
 {
-  struct MaskItem *conf = NULL;
+  const struct GecosItem *gecos = NULL;
 
   if (HasFlag(source_p, FLAGS_EXEMPTXLINE))
     return 0;
 
-  if ((conf = find_matching_name_conf(CONF_XLINE, source_p->info, NULL, NULL, 0)))
+  if ((gecos = gecos_find(source_p->info, match)))
   {
-    ++conf->count;
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "X-line Rejecting [%s] [%s], user %s [%s]",
-                         source_p->info, conf->reason,
+                         source_p->info, gecos->reason,
                          get_client_name(source_p, HIDE_IP),
                          source_p->sockhost);
 
