@@ -8,7 +8,7 @@
 ** /dev/random for salt generation added by
 ** Aaron Sethman <androsyn@ratbox.org>
 **
-** $Id: mkpasswd.c 6589 2015-10-21 18:44:03Z michael $
+** $Id: mkpasswd.c 7329 2016-02-18 21:07:50Z michael $
 */
 
 #include <stdio.h>
@@ -315,7 +315,7 @@ generate_random_salt(char *salt, unsigned int length)
 
   buf = calloc(1, length);
 
-  if (read(fd, buf, length) != length)
+  if (read(fd, buf, length) != (ssize_t)length)
   {
     close(fd);
     free(buf);
